<?php

namespace App\Http\Controllers;

use Flash;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Response;
use Prettus\Validator\Exceptions\ValidatorException;
use DB;

class LabeldescController extends Controller
{
    public function index()
    {
         $label_description = DB::table('lang_eng_and_arabic')->orderBy('id','DESC')->paginate(10);
          $labels = DB::table('lang_translation')->where('status','=','1')->orderBy('id','DESC')->paginate(10);
         return view('label_description/index', ['label_description' => $label_description,'labels'=>$labels,
      ]);
    }

    /**
     * Display a user profile.
     *
     * @param
     * @return Response
     */
    public function profile()
    {
        $user = $this->VehicleRepository->findWithoutFail(auth()->id());
        unset($user->password);
        $customFields = false;
        $role = $this->roleRepository->pluck('name', 'name');
        $rolesSelected = $user->getRoleNames()->toArray();
        $customFieldsValues = $user->customFieldsValues()->with('customField')->get();
        //dd($customFieldsValues);
        $hasCustomField = in_array($this->VehicleRepository->model(), setting('custom_field_models', []));
        if ($hasCustomField) {
            $customFields = $this->customFieldRepository->findByField('custom_field_model', $this->VehicleRepository->model());
            $customFields = generateCustomField($customFields, $customFieldsValues);
        }
        return view('settings.users.profile', compact(['user', 'role', 'rolesSelected', 'customFields', 'customFieldsValues']));
    }

    /**
     * Show the form for creating a new User.
     *
     * @return Response
     */
    public function create()
    {
        $labels = DB::table('lang_translation')->where('id','!=','0')->get();
        return view('label_description.create',['labels'=>$labels]);
        
    }

    /**
     * Store a newly created User in storage.
     *
     * @param CreateUserRequest $request
     *
     * @return Response
     */
    public function store(Request $request)
    {
        if (env('APP_DEMO', false)) {
            Flash::warning('This is only demo app you can\'t change this section ');
            return redirect(route('users.index'));
        }
        try {
           $date_added	= date('Y-m-d H:i:s');
      DB::table('lang_eng_and_arabic')->insert(['description_en'=>$request->description_en,'label_id'=>$request->label_id,'description_ar'=>$request->description_ar,'status'=>$request->status,'created'=>$date_added]);
        } catch (ValidatorException $e) {
            Flash::error($e->getMessage());
        }

        Flash::success('saved successfully.');

        return redirect(route('label_description.index'));
    }

    /**
     * Display the specified User.
     *
     * @param int $id
     *
     * @return Response
     */
    public function show($id)
    {
        $user = $this->VehicleRepository->findWithoutFail($id);

        if (empty($user)) {
            Flash::error('User not found');

            return redirect(route('label_description.index'));
        }

        return view('settings.users.profile')->with('user', $user);
    }

    public function loginAsUser(Request $request, $id)
    {
        $user = $this->VehicleRepository->findWithoutFail($id);
        if (empty($user)) {
            Flash::error('User not found');
            return redirect(route('users.index'));
        }
        auth()->login($user, true);
        if (auth()->id() !== $user->id) {
            Flash::error('User not found');
        }
        return redirect(route('users.profile'));
    }

    /**
     * Show the form for editing the specified User.
     *
     * @param int $id
     *
     * @return Response
     */
   
    
    public function edit($id)
    {
        if (!auth()->user()->hasRole('admin') && $id != auth()->id()) {
            Flash::error('Permission denied');
            return redirect(route('label_description.index'));
        }
       
	
	
	    $result = array();		
		$result['message'] = array();
		
		$editlabeldesc = DB::table('lang_eng_and_arabic')->where('id','=',$id)->get();
		$label_id=isset($editlabeldesc[0]->label_id) ? $editlabeldesc[0]->label_id : '';	
		$result['editlabeldesc'] = $editlabeldesc;		
		$labels = DB::table('lang_translation')->where('id','!=','0')->get();
		$result['labels'] = $labels;
		
		
        if (empty($editlabeldesc)) {
            Flash::error('label desc not found');

            return redirect(route('label_description.index'));
        }
        //return view('vehicle.edit')->with('vehicle', $editvehicle);
        
        return view("label_description.edit",['editlabeldesc' => $editlabeldesc])->with('result',$result);
        
    }

    /**
     * Update the specified User in storage.
     *
     * @param int $id
     * @param UpdateUserRequest $request
     *
     * @return Response
     */
    public function update($id,Request $request)
    {
        if (env('APP_DEMO', false)) {
            Flash::warning('This is only demo app you can\'t change this section ');
            return redirect(route('users.profile'));
        }
        if (!auth()->user()->hasRole('admin') && $id != auth()->id()) {
            Flash::error('Permission denied');
            return redirect(route('users.profile'));
        }

        $langtype = DB::table('lang_eng_and_arabic')->where('id','=',$request->id)->get();
 $label = DB::table('lang_translation')->where('id','!=','0')->get();
        if (empty($langtype)) {
            Flash::error('label not found');
            return redirect(route('users.profile'));
        }
        try {
        $last_modified=date('Y-m-d H:i:s');
		DB::table('lang_eng_and_arabic')->where('id','=',$id)->update(['description_en'=>$request->description_en,'label_id'=>$request->label_id,'description_ar'=>$request->description_ar,'status'=>$request->status,'modified'=>$last_modified]);
        } catch (ValidatorException $e) {
            Flash::error($e->getMessage());
        }


        Flash::success('Label Description updated successfully.');

        return redirect()->back();

    }

    /**
     * Remove the specified User from storage.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy($id)
    {
        if (env('APP_DEMO', false)) {
            Flash::warning('This is only demo app you can\'t change this section ');
            return redirect(route('users.index'));
        }
        
        $lang_eng_and_arabic=DB::table('lang_eng_and_arabic')->where('id','=',$id)->get();
		
        if (empty($lang_eng_and_arabic)) {
            Flash::error('Label desc not found');

            return redirect(route('label_description.index'));
        }

        DB::table('lang_eng_and_arabic')->where('id','=',$id)->delete();

        Flash::success('Label desc deleted successfully.');

        return redirect(route('label_description.index'));
    }

    /**
     * Remove Media of User
     * @param Request $request
     */
    public function removeMedia(Request $request)
    {
        if (env('APP_DEMO', false)) {
            Flash::warning('This is only demo app you can\'t change this section ');
        } else {
            if (auth()->user()->can('medias.delete')) {
                $input = $request->all();
                $user = $this->VehicleRepository->findWithoutFail($input['id']);
                try {
                    if ($user->hasMedia($input['collection'])) {
                        $user->getFirstMedia($input['collection'])->delete();
                    }
                } catch (\Exception $e) {
                    Log::error($e->getMessage());
                }
            }
        }
    }
}
