<?php

namespace App\Http\Controllers;

use Flash;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Response;
use Prettus\Validator\Exceptions\ValidatorException;
use DB;

class LabelsController extends Controller
{
    public function index()
    {
         $lang_translation = DB::table('lang_translation')->orderBy('id','DESC')->paginate(10);
         return view('labels/index', ['lang_translation' => $lang_translation
      ]);
    }



    /**
     * Show the form for creating a new User.
     *
     * @return Response
     */
    public function create()
    {
        $store = DB::table('store_group')->where('group_id','!=','0')->get();
        return view('labels.create',['store'=>$store]);
        
    }

    /**
     * Store a newly created User in storage.
     *
     * @param CreateUserRequest $request
     *
     * @return Response
     */
    public function store(Request $request)
    {
        if (env('APP_DEMO', false)) {
            Flash::warning('This is only demo app you can\'t change this section ');
            return redirect(route('users.index'));
        }
        try {
           $date_added	= date('Y-m-d H:i:s');
      DB::table('lang_translation')->insert(['label_name'=>$request->label_name,'status'=>$request->status,'created'=>$date_added]);
        } catch (ValidatorException $e) {
            Flash::error($e->getMessage());
        }

        Flash::success('saved successfully.');

        return redirect(route('labels.index'));
    }

    /**
     * Display the specified User.
     *
     * @param int $id
     *
     * @return Response
     */
    public function show($id)
    {
        $user = $this->VehicleRepository->findWithoutFail($id);

        if (empty($user)) {
            Flash::error('User not found');

            return redirect(route('labels.index'));
        }

        return view('settings.users.profile')->with('user', $user);
    }

    public function loginAsUser(Request $request, $id)
    {
        $user = $this->VehicleRepository->findWithoutFail($id);
        if (empty($user)) {
            Flash::error('User not found');
            return redirect(route('users.index'));
        }
        auth()->login($user, true);
        if (auth()->id() !== $user->id) {
            Flash::error('User not found');
        }
        return redirect(route('users.profile'));
    }

    /**
     * Show the form for editing the specified User.
     *
     * @param int $id
     *
     * @return Response
     */
    public function edit($id)
    {
        if (!auth()->user()->hasRole('admin') && $id != auth()->id()) {
            Flash::error('Permission denied');
            return redirect(route('labels.index'));
        }
       
	
	
	    $result = array();		
		$result['message'] = array();
		
		$editlabel = DB::table('lang_translation')->where('id','=',$id)->get();
		$result['editlabel'] = $editlabel;		
		
		
        if (empty($editlabel)) {
            Flash::error('Label not found');

            return redirect(route('labels.index'));
        }
        
        return view("labels.edit",['editlabel' => $editlabel])->with('result',$result);
        
    }

    /**
     * Update the specified User in storage.
     *
     * @param int $id
     * @param UpdateUserRequest $request
     *
     * @return Response
     */
    public function update($id,Request $request)
    {
        if (env('APP_DEMO', false)) {
            Flash::warning('This is only demo app you can\'t change this section ');
            return redirect(route('users.profile'));
        }
        if (!auth()->user()->hasRole('admin') && $id != auth()->id()) {
            Flash::error('Permission denied');
            return redirect(route('users.profile'));
        }

        $lang_translation = DB::table('lang_translation')->where('id','=',$request->id)->get();
        if (empty($lang_translation)) {
            Flash::error('Label not found');
            return redirect(route('users.profile'));
        }
        try {
        $last_modified=date('Y-m-d H:i:s');
		DB::table('lang_translation')->where('id','=',$id)->update(['label_name'=>$request->label_name,'status'=>$request->status,'modified'=>$last_modified]);
        } catch (ValidatorException $e) {
            Flash::error($e->getMessage());
        }


        Flash::success('Label updated successfully.');

        return redirect()->back();

    }

    /**
     * Remove the specified User from storage.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy($id)
    {
        if (env('APP_DEMO', false)) {
            Flash::warning('This is only demo app you can\'t change this section ');
            return redirect(route('users.index'));
        }
        
        $lang_translation=DB::table('lang_translation')->where('id','=',$id)->get();
		
        if (empty($lang_translation)) {
            Flash::error('Label not found');

            return redirect(route('labels.index'));
        }

        DB::table('lang_translation')->where('id','=',$id)->delete();

        Flash::success('label deleted successfully.');

        return redirect(route('labels.index'));
    }

    /**
     * Remove Media of User
     * @param Request $request
     */
    public function removeMedia(Request $request)
    {
        if (env('APP_DEMO', false)) {
            Flash::warning('This is only demo app you can\'t change this section ');
        } else {
            if (auth()->user()->can('medias.delete')) {
                $input = $request->all();
                $user = $this->VehicleRepository->findWithoutFail($input['id']);
                try {
                    if ($user->hasMedia($input['collection'])) {
                        $user->getFirstMedia($input['collection'])->delete();
                    }
                } catch (\Exception $e) {
                    Log::error($e->getMessage());
                }
            }
        }
    }
}
