<?php

namespace App\Http\Controllers;

use App\Criteria\Orders\OrdersOfUserCriteria;
use App\Criteria\Users\ClientsCriteria;
use App\Criteria\Users\DriversCriteria;
use App\Criteria\Users\PickerCriteria;
use App\Criteria\Users\DriversOfMarketCriteria;
use App\DataTables\OrderDataTable;
use App\DataTables\ProductOrderDataTable;
use App\Events\OrderChangedEvent;
use App\Http\Requests\CreateOrderRequest;
use App\Http\Requests\UpdateOrderRequest;
use App\Notifications\AssignedOrder;
use App\Notifications\StatusChangedOrder;
use App\Repositories\CustomFieldRepository;
use App\Repositories\NotificationRepository;
use App\Repositories\OrderRepository;
use App\Repositories\OrderitemRepository;
use \stdClass;
use App\Repositories\OrderStatusRepository;
use App\Repositories\PaymentRepository;
use App\Repositories\UserRepository;
use Flash;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Facades\Response;
use Prettus\Validator\Exceptions\ValidatorException;
use DB;
use Redirect;
class OrderController extends Controller
{
    /** @var  OrderRepository */
    private $orderRepository;
    private $orderitemRepository;
    /**
     * @var CustomFieldRepository
     */
    private $customFieldRepository;

    /**
     * @var UserRepository
     */
    private $userRepository;
    /**
     * @var OrderStatusRepository
     */
    private $orderStatusRepository;
    /** @var  NotificationRepository */
    private $notificationRepository;
    /** @var  PaymentRepository */
    private $paymentRepository;

    public function __construct(OrderRepository $orderRepo, OrderitemRepository $orderitem, CustomFieldRepository $customFieldRepo, UserRepository $userRepo
        , OrderStatusRepository $orderStatusRepo, NotificationRepository $notificationRepo, PaymentRepository $paymentRepo)
    {
        parent::__construct();
        $this->OrderitemRepository=$orderitem;
        $this->orderRepository = $orderRepo;
        $this->customFieldRepository = $customFieldRepo;
        $this->userRepository = $userRepo;
        $this->orderStatusRepository = $orderStatusRepo;
        $this->notificationRepository = $notificationRepo;
        $this->paymentRepository = $paymentRepo;
    }

    /**
     * Display a listing of the Order.
     *
     * @param OrderDataTable $orderDataTable
     * @return Response
     */
    public function index(OrderDataTable $orderDataTable)
    {
           $domain_address_code = session('domain_address_setup');
           if(empty($domain_address_code)){
                $domain_address_code='JO';
           }
            $sqlcountry=DB::select("SELECT value,GROUP_CONCAT(scope_id SEPARATOR ',') AS `store_id`  FROM `core_config_data` WHERE path='general/country/destinations' AND value='$domain_address_code' order by config_id asc"); 
            foreach($sqlcountry as $value){
            $store_id=explode(',',$value->store_id);
            if(in_array('0',$store_id)){
             $stores=DB::select("SELECT scope_id FROM `core_config_data` WHERE path='general/country/destinations' and scope='stores' and value='$domain_address_code'");  
             $scope_id=array();
             foreach($stores as $value1){
                 array_push($scope_id,$value1->scope_id);
             }
             $storesgroup=DB::select("SELECT GROUP_CONCAT(store_id SEPARATOR ',') as store_id,store_group.group_id FROM `store` INNER JOIN store_group ON store.group_id=store_group.group_id WHERE store_id!='0' group by store_group.group_id");  
             $store_id1=array();
             foreach($storesgroup as $value2){
                 $store_ids=explode(',',$value2->store_id);
                 foreach($store_ids as $store_ids1){
                 if(in_array($store_ids1,$scope_id)){
                 array_push($store_id1,$store_ids1);
                 }
                 }
             }
             $implode=$store_id1;
            }else{
             $implode=explode(',',$value->store_id);  
            }
            }
            
            $productType = isset($_GET['type']) ? $_GET['type'] : 'Grocery';
            $order_id = isset($_GET['order_id']) ? $_GET['order_id'] : '';
            $paginate_count = isset($_GET['paginate_count']) ? $_GET['paginate_count'] : '10';
            $sales_order='';
            if($productType == "Grocery"){
                if(!empty($order_id)){
                    $sales_order = DB::table('sales_order')->leftJoin('sales_order_item', 'sales_order_item.order_id', '=', 'sales_order.entity_id')->select('sales_order.*')->whereIn('sales_order.store_id',$implode)->whereNotIn('sales_order.status',['payment_review','closed','pending'])->whereNotIn('sales_order_item.order_status_id',['12'])->orderBy('sales_order.created_at', 'desc')->where('sales_order_item.delivery_from','=','Grocery')->where('sales_order.increment_id', 'LIKE',"%{$order_id}%")->orderBy('sales_order.created_at', 'desc')->groupBy('sales_order.entity_id')->paginate($paginate_count);
                }else{
                    $sales_order = DB::table('sales_order')->leftJoin('sales_order_item', 'sales_order_item.order_id', '=', 'sales_order.entity_id')->select('sales_order.*')->whereIn('sales_order.store_id',$implode)->whereNotIn('sales_order.status',['payment_review','closed','pending'])->whereNotIn('sales_order_item.order_status_id',['12'])->orderBy('sales_order.created_at', 'desc')->where('sales_order_item.delivery_from','=','Grocery')->orderBy('sales_order.created_at', 'desc')->groupBy('sales_order.entity_id')->paginate($paginate_count);
                }
            } else if($productType == "Warehouse") {
                if(!empty($order_id)){
                    $sales_order = DB::table('sales_order')->leftJoin('sales_order_item', 'sales_order_item.order_id', '=', 'sales_order.entity_id')->select('sales_order.*')->whereIn('sales_order.store_id',$implode)->whereNotIn('sales_order.status',['payment_review','closed','pending'])->whereNotIn('sales_order_item.order_status_id',['12'])->orderBy('sales_order.created_at', 'desc')->where('sales_order_item.delivery_from','=','Warehouse')->where('sales_order.increment_id', 'LIKE',"%{$order_id}%")->orderBy('sales_order.created_at', 'desc')->groupBy('sales_order.entity_id')->paginate($paginate_count);
                }else{
                    $sales_order = DB::table('sales_order')->leftJoin('sales_order_item', 'sales_order_item.order_id', '=', 'sales_order.entity_id')->select('sales_order.*')->whereIn('sales_order.store_id',$implode)->whereNotIn('sales_order.status',['payment_review','closed','pending'])->whereNotIn('sales_order_item.order_status_id',['12'])->orderBy('sales_order.created_at', 'desc')->where('sales_order_item.delivery_from','=','Warehouse')->orderBy('sales_order.created_at', 'desc')->groupBy('sales_order.entity_id')->paginate($paginate_count);
                }
            } else if($productType == "Supplier"){
                if(!empty($order_id)){
                    $sales_order = DB::table('sales_order')->leftJoin('sales_order_item', 'sales_order_item.order_id', '=', 'sales_order.entity_id')->select('sales_order.*')->whereIn('sales_order.store_id',$implode)->whereNotIn('sales_order.status',['payment_review','closed','pending'])->whereNotIn('sales_order_item.order_status_id',['12'])->orderBy('sales_order.created_at', 'desc')->where('sales_order_item.delivery_from','=','Supplier')->where('sales_order.increment_id', 'LIKE',"%{$order_id}%")->orderBy('sales_order.created_at', 'desc')->groupBy('sales_order.entity_id')->paginate($paginate_count);
                }else{
                    $sales_order = DB::table('sales_order')->leftJoin('sales_order_item', 'sales_order_item.order_id', '=', 'sales_order.entity_id')->select('sales_order.*')->whereIn('sales_order.store_id',$implode)->whereNotIn('sales_order.status',['payment_review','closed','pending'])->whereNotIn('sales_order_item.order_status_id',['12'])->orderBy('sales_order.created_at', 'desc')->where('sales_order_item.delivery_from','=','Supplier')->orderBy('sales_order.created_at', 'desc')->groupBy('sales_order.entity_id')->paginate($paginate_count);
                }
            }
            
         return view('orders.index')->with('sales_order',$sales_order)->with('paginate_count', $paginate_count);
         
         //return $orderDataTable->render('orders.index');
    }
    
     public function oldIndexCode(OrderDataTable $orderDataTable)
    {
       return $orderDataTable->render('orders.oldindexcode');
    }
    
    public function orderdelivery($id)
    {
         $sales_order = DB::table('sales_order')->where('entity_id',$id)->orderBy('entity_id','DESC')->get();
         $product_type = isset($_GET["product_type"])? $_GET["product_type"] : "";
         return view('orders/delivery', ['entity_id' => $id, "product_type" => $product_type]);
    }
    public function ordertax($id)
    {
         $sales_order = DB::table('sales_order')->where('entity_id',$id)->orderBy('entity_id','DESC')->get();
         return view('orders/tax', ['entity_id' => $id]);
    }
    /**
     * Show the form for creating a new Order.
     *
     * @return Response
     */
    public function create()
    {
        $user = $this->userRepository->getByCriteria(new ClientsCriteria())->pluck('name', 'id');
        $driver = $this->userRepository->getByCriteria(new DriversCriteria())->pluck('name', 'id');

        $orderStatus = $this->orderStatusRepository->pluck('status', 'id');

        $hasCustomField = in_array($this->orderRepository->model(), setting('custom_field_models', []));
        if ($hasCustomField) {
            $customFields = $this->customFieldRepository->findByField('custom_field_model', $this->orderRepository->model());
            $html = generateCustomField($customFields);
        }
        return view('orders.create')->with("customFields", isset($html) ? $html : false)->with("user", $user)->with("driver", $driver)->with("orderStatus", $orderStatus);
    }

    /**
     * Store a newly created Order in storage.
     *
     * @param CreateOrderRequest $request
     *
     * @return Response
     */
    public function store(CreateOrderRequest $request)
    {
        $input = $request->all();
        $customFields = $this->customFieldRepository->findByField('custom_field_model', $this->orderRepository->model());
        try {
            $order = $this->orderRepository->create($input);
            $order->customFieldsValues()->createMany(getCustomFieldsValues($customFields, $request));

        } catch (ValidatorException $e) {
            Flash::error($e->getMessage());
        }

        Flash::success(__('lang.saved_successfully', ['operator' => __('lang.order')]));

        return redirect(route('orders.index'));
    }

    /**
     * Display the specified Order.
     *
     * @param int $id
     * @param ProductOrderDataTable $productOrderDataTable
     *
     * @return Response
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */

    public function show(ProductOrderDataTable $productOrderDataTable, $id)
    {
        
      //  $this->orderRepository->pushCriteria(new OrdersOfUserCriteria(auth()->id()));
        $type=isset($_GET['type']) ? $_GET['type'] : '' ;
        $order = $this->orderRepository->findWithoutFail($id);
        $order1 = $this->orderRepository->leftJoin('order_statuses', 'order_statuses.id', '=', 'sales_order.order_status_id')->select('order_statuses.status')->where('entity_id',$id)->get();
        if (empty($order)) {
            Flash::error(__('lang.not_found', ['operator' => __('lang.order')]));

            return redirect(route('orders.index'));
        }
        $subtotal = 0;

        foreach ($order->productOrders as $productOrder) {
            // foreach ($productOrder->options as $option) {
            //     $productOrder->price += $option->price;
            // }
            $subtotal += $productOrder->price;
        }
        $orderStatues='';
        foreach ($order1 as $orderSt) {
            $orderStatues = $orderSt->status;
        }
        //  $getaddress = DB::table('customer_address_entity')->where('parent_id',$order->customer_id)->first();
        $getaddress = DB::table('sales_order_address')->where('parent_id','=',$id)->where('address_type','=','shipping')->first();
        $customer_address_id=isset($getaddress->customer_address_id) ? $getaddress->customer_address_id :'';
        $getaddress1 = DB::table('customer_address_entity')->where('entity_id','=',$customer_address_id)->first();
        $getpaystatus = DB::table('sales_order_payment')->where('parent_id',$id)->first();
        
     $orderpicker = DB::table('sales_order')->where('entity_id',$id)->first();
      if($type=="Grocery"){
      $orderpicker1 = DB::table('sales_order_item')->where('order_id','=',$id)->where('delivery_from','=',$type)->first();
      } else if($type == "Warehouse"){
       $orderpicker1 = DB::table('sales_order_item')->where('order_id','=',$id)->where('delivery_from','=',$type)->first();  
      } else if($type == "Supplier"){
       $orderpicker1 = DB::table('sales_order_item')->where('order_id','=',$id)->where('delivery_from','=',$type)->first(); 
      }
      $orderpicker1driver=isset($orderpicker1->driver_id) ? $orderpicker1->driver_id :'';
       $orderpicker1picker=isset($orderpicker1->picker_id) ? $orderpicker1->picker_id :'';
      $driver = DB::table('users')->where('id','=',$orderpicker1driver)->first();
       //echo $orderpicker->picker_id; exit;
      $picker = DB::table('users')->where('id','=',$orderpicker1picker)->first();
        
    //     $orderpicker = DB::table('sales_order')->where('entity_id',$id)->first();
    //   $picker = DB::table('users')->where('id',$orderpicker->picker_id)->first();
   $getbag = DB::table('add_to_bag')->select(DB::raw("SUM(qty) as qty"))->where('order_id',$id)->get();
        $taxAmount = $order['base_shipping_amount'];
        $productOrderDataTable->id = $id;
        $productType = isset($_GET['type']) ? $_GET['type'] : 'Grocery';
        $getorder = '';
    if($productType == "Grocery"){
        $getorder = DB::table('sales_order_item')
        ->leftjoin('add_to_bag', function ($join) {
           $join->on('sales_order_item.product_id', '=', 'add_to_bag.product_id');
             $join->on('sales_order_item.order_id', '=', 'add_to_bag.order_id');  
       })
          ->leftjoin('sales_stock', function ($join) {
           $join->on('sales_order_item.product_id', '=', 'sales_stock.product_id');
             $join->on('sales_order_item.order_id', '=', 'sales_stock.order_id');  
       })->where('sales_order_item.delivery_from','=','Grocery')
        ->select('sales_order_item.*', 'sales_stock.qty as outofstockqty','add_to_bag.qty as inbagqty')->where('sales_order_item.order_id',$id)->orderBy('sales_order_item.item_id','ASC')->get();
        
        $current_status = DB::table('order_statuses')
    ->Join('sales_order_item','order_statuses.id','=','sales_order_item.order_status_id')
    ->where('sales_order_item.order_id',$id)
    ->where('sales_order_item.delivery_from','=','Grocery')
    ->select('order_statuses.status')
    ->first();
    } else if($productType == "Warehouse"){
        $getorder = DB::table('sales_order_item')
        ->leftjoin('add_to_bag', function ($join) {
           $join->on('sales_order_item.product_id', '=', 'add_to_bag.product_id');
             $join->on('sales_order_item.order_id', '=', 'add_to_bag.order_id');  
       })
          ->leftjoin('sales_stock', function ($join) {
           $join->on('sales_order_item.product_id', '=', 'sales_stock.product_id');
             $join->on('sales_order_item.order_id', '=', 'sales_stock.order_id');  
       })->where('sales_order_item.delivery_from','=','Warehouse')
        ->select('sales_order_item.*', 'sales_stock.qty as outofstockqty','add_to_bag.qty as inbagqty')->where('sales_order_item.order_id',$id)->orderBy('sales_order_item.item_id','ASC')->get();
        
        $current_status = DB::table('order_statuses')
    ->Join('sales_order_item','order_statuses.id','=','sales_order_item.order_status_id')
    ->where('sales_order_item.order_id',$id)
    ->where('sales_order_item.delivery_from','=','Warehouse')
    ->select('order_statuses.status')
    ->first();
    } else if($productType == "Supplier"){
        $getorder = DB::table('sales_order_item')
        ->leftjoin('add_to_bag', function ($join) {
           $join->on('sales_order_item.product_id', '=', 'add_to_bag.product_id');
             $join->on('sales_order_item.order_id', '=', 'add_to_bag.order_id');  
       })
          ->leftjoin('sales_stock', function ($join) {
           $join->on('sales_order_item.product_id', '=', 'sales_stock.product_id');
             $join->on('sales_order_item.order_id', '=', 'sales_stock.order_id');  
       })->where('sales_order_item.delivery_from','=','Supplier')
        ->select('sales_order_item.*', 'sales_stock.qty as outofstockqty','add_to_bag.qty as inbagqty')->where('sales_order_item.order_id',$id)->orderBy('sales_order_item.item_id','ASC')->get();
        
        $current_status = DB::table('order_statuses')
    ->Join('sales_order_item','order_statuses.id','=','sales_order_item.order_status_id')
    ->where('sales_order_item.order_id',$id)
    ->where('sales_order_item.delivery_from','=','Supplier')
    ->select('order_statuses.status')
    ->first();
    }
    $strid = isset($order->productOrders['0']->store_id)? $order->productOrders['0']->store_id : "";
        $getstore = DB::table('store_group')->where('group_id',$strid)->first();
          if($getstore){
           $getstorename=$getstore->name;
        }
         else{
               $getstorename="";
         }
        $update = strtotime($order->updated_at);
         $delivery = strtotime($order->created_at);
        $getzone=date_default_timezone_get();
        
          date_default_timezone_set($getzone);
          $created_at=date("Y-m-d", $update);
          
         $updated_at=date("Y-d-m T G:i", $update);
         $paym=json_decode($getpaystatus->additional_information);
         
       
        //  if($paym->method_title=="DebitCard | CreditCard"){
        //     $pay="Card Payment"; 
        //  }else{
        //      $pay=$paym->method_title;
        //  }
        
        $pay=$paym->method_title;
        // $pay=$getpaystatus->method;
        
        $sales_order_item_configurable = DB::select("SELECT soi.sku FROM sales_order_item as soi WHERE soi.order_id='$id' AND soi.product_type='Configurable'");
        // print_r($sales_order_item_configurable);exit;
        
        //Sub Status Check Start
            $currentMainStatus1 = DB::select("SELECT status FROM sales_order WHERE entity_id='$id'");
            $currentMainStatus = isset($currentMainStatus1[0]->status)? $currentMainStatus1[0]->status : "";
            $resulltts=DB::select("SELECT sub_status FROM sales_order_item WHERE order_id='$id' and product_type='simple' and delivery_from='$productType'");
            $aar = array();
            foreach($resulltts as $resultss1){
                if(empty($resultss1->sub_status) || is_null($resultss1->sub_status)){
                        $subStatus='';
                        if($currentMainStatus == "processing"){
                                $subStatus = $currentMainStatus;
                        }else{
                                $subStatus = "Order Placed";
                        }
                        array_push($aar, $subStatus);
                }else{
                        array_push($aar, $resultss1->sub_status);
                }
            }
            // print_r($aar);
            $subStatusArrayCount = array_count_values($aar);
            
            $stCheck = '';
            if(($currentMainStatus == 'pending') || ($currentMainStatus == 'canceled')){
                $stCheck = $currentMainStatus;
            }else{
                if(count($subStatusArrayCount)>1){
                    foreach($subStatusArrayCount as $key=>$subStatusArrayCount1){
                        if($key != "canceled"){
                            $stCheck = $key;
                        }
                    }
                }else{
                    $stCheck = key($subStatusArrayCount);
                }
            }
        //Sub Status Check End
        
        $paymethodd = DB::table('sales_order_payment')->where('parent_id',$id)->select('method')->first();
        $paymethod = isset($paymethodd->method)? $paymethodd->method : '';
        
        $cusmId1 = DB::table('sales_order')->where('entity_id',$id)->first();
        $cusmId = isset($cusmId1->customer_id)? $cusmId1->customer_id : "";
        $customersigninphone1 = DB::table('customer_entity_varchar')->where('entity_id',$cusmId)->first();
        $customersigninphone = isset($customersigninphone1->value)? $customersigninphone1->value : "-";
        
        $getbagqtty = isset($getbag['0']->qty)? $getbag['0']->qty : "";
        
        return $productOrderDataTable->render('orders.show', ["order" => $order, "total" => $order['base_grand_total'],"picker" => $picker,"driver" => $driver,"getbag"=> $getbagqtty, "subtotal" => $order['base_subtotal'],"taxAmount" => $taxAmount,"getorder"=> $getorder,"getaddress"=> $getaddress ,"getpaystatus"=> $pay,"storename"=>$getstorename,"updated_at"=>$updated_at,"created_at"=>$created_at, "orderStatusess"=>$current_status->status, "getaddress1"=>$getaddress1, "sales_order_item_configurable"=>$sales_order_item_configurable])->with("stCheck", $stCheck)->with('paayymethod', $paymethod)->with("customersigninphone",$customersigninphone)->with('customerId1',$cusmId)->with('orderId', $id);
    }

    /**
     * Show the form for editing the specified Order.
     *
     * @param int $id
     *
     * @return Response
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function edit($id)
    {
       //$this->orderRepository->pushCriteria(new OrdersOfUserCriteria(auth()->id()));
        $type=isset($_GET['type']) ? $_GET['type'] : '' ;
        $order = $this->orderRepository->findWithoutFail($id);
        $order1 = $this->orderRepository->leftJoin('order_statuses', 'order_statuses.id', '=', 'sales_order.order_status_id')->select('order_statuses.status')->where('entity_id',$id)->get();
        if (empty($order)) {
            Flash::error(__('lang.not_found', ['operator' => __('lang.order')]));

            return redirect(route('orders.index'));
        }
        $subtotal = 0;

        foreach ($order->productOrders as $productOrder) {
            // foreach ($productOrder->options as $option) {
            //     $productOrder->price += $option->price;
            // }
            $subtotal += $productOrder->price;
        }
        $orderStatues='';
        foreach ($order1 as $orderSt) {
            $orderStatues = $orderSt->status;
        }
        $taxAmount = $order['base_shipping_amount'];
        $market = $order->productOrders()->first();
        $market = isset($market) ? $market->product['market_id'] : 0;

        $user = $this->userRepository->getByCriteria(new ClientsCriteria())->pluck('name', 'id');
        //$driver = $this->userRepository->getByCriteria(new DriversCriteria($market))->pluck('name', 'id');
       //$picker = $this->userRepository->getByCriteria(new PickerCriteria($market))->pluck('name', 'id');
      
      $orderpicker = DB::table('sales_order')->where('entity_id',$id)->first();
      if($type=="Grocery"){
      $orderpicker1 = DB::table('sales_order_item')->where('order_id','=',$id)->where('delivery_from','=',$type)->first();
      } else if($type == "Warehouse"){
       $orderpicker1 = DB::table('sales_order_item')->where('order_id','=',$id)->where('delivery_from','=',$type)->first();  
      } else if($type == "Supplier"){
       $orderpicker1 = DB::table('sales_order_item')->where('order_id','=',$id)->where('delivery_from','=',$type)->first(); 
      }
      $orderpicker1driver=isset($orderpicker1->driver_id) ? $orderpicker1->driver_id :'';
       $orderpicker1picker=isset($orderpicker1->picker_id) ? $orderpicker1->picker_id :'';
      $driver = DB::table('users')->where('id','=',$orderpicker1driver)->first();
       //echo $orderpicker->picker_id; exit;
      $picker = DB::table('users')->where('id','=',$orderpicker1picker)->first();
        $orderStatus = $this->orderStatusRepository->pluck('status', 'id');

        $customFieldsValues = $order->customFieldsValues()->with('customField')->get();
        $customFields = $this->customFieldRepository->findByField('custom_field_model', $this->orderRepository->model());
        $hasCustomField = in_array($this->orderRepository->model(), setting('custom_field_models', []));
        if ($hasCustomField) {
            $html = generateCustomField($customFields, $customFieldsValues);
        }
        
    // $getaddress = DB::table('customer_address_entity')->where('parent_id',$order->customer_id)->first();
    $getaddress = DB::table('sales_order_address')->where('parent_id','=',$id)->where('address_type','=','shipping')->first();
    $customer_address_id=isset($getaddress->customer_address_id) ? $getaddress->customer_address_id :'';
    $getaddress1 = DB::table('customer_address_entity')->where('entity_id','=',$customer_address_id)->first();
    $getbag = DB::table('add_to_bag')->select(DB::raw("SUM(qty) as qty"))->where('order_id',$id)->get();

    $getpaystatus = DB::table('sales_order_payment')->where('parent_id',$id)->first();
    $productType = isset($_GET['type']) ? $_GET['type'] : 'Grocery';
    $getorder = '';
    $productID = '';
    $current_status = '';
    if($productType == "Grocery"){
        $getorder = DB::table('sales_order_item')
        ->leftjoin('add_to_bag', function ($join) {
           $join->on('sales_order_item.product_id', '=', 'add_to_bag.product_id');
             $join->on('sales_order_item.order_id', '=', 'add_to_bag.order_id');  
       })
          ->leftjoin('sales_stock', function ($join) {
           $join->on('sales_order_item.product_id', '=', 'sales_stock.product_id');
             $join->on('sales_order_item.order_id', '=', 'sales_stock.order_id');  
       })->where('sales_order_item.delivery_from','=','Grocery')
        ->select('sales_order_item.*', 'sales_stock.qty as outofstockqty','add_to_bag.qty as inbagqty')->where('sales_order_item.order_id',$id)->orderBy('sales_order_item.item_id','DESC')->get();
        
        $current_status = DB::table('order_statuses')
    ->Join('sales_order_item','order_statuses.id','=','sales_order_item.order_status_id')
    ->where('sales_order_item.order_id',$id)
    ->where('sales_order_item.delivery_from','=','Grocery')
    ->select('order_statuses.status')
    ->first();
        
    } else if($productType == "Warehouse"){
         $getorder = DB::table('sales_order_item')
        ->leftjoin('add_to_bag', function ($join) {
           $join->on('sales_order_item.product_id', '=', 'add_to_bag.product_id');
             $join->on('sales_order_item.order_id', '=', 'add_to_bag.order_id');  
       })
          ->leftjoin('sales_stock', function ($join) {
           $join->on('sales_order_item.product_id', '=', 'sales_stock.product_id');
             $join->on('sales_order_item.order_id', '=', 'sales_stock.order_id');  
       })->where('sales_order_item.delivery_from','=','Warehouse')
        ->select('sales_order_item.*', 'sales_stock.qty as outofstockqty','add_to_bag.qty as inbagqty')->where('sales_order_item.order_id',$id)->orderBy('sales_order_item.item_id','DESC')->get();
        
        $current_status = DB::table('order_statuses')
    ->Join('sales_order_item','order_statuses.id','=','sales_order_item.order_status_id')
    ->where('sales_order_item.order_id',$id)
    ->where('sales_order_item.delivery_from','=','Warehouse')
    ->select('order_statuses.status')
    ->first();
    } else if($productType == "Supplier"){
        $getorder = DB::table('sales_order_item')
        ->leftjoin('add_to_bag', function ($join) {
           $join->on('sales_order_item.product_id', '=', 'add_to_bag.product_id');
             $join->on('sales_order_item.order_id', '=', 'add_to_bag.order_id');  
       })
          ->leftjoin('sales_stock', function ($join) {
           $join->on('sales_order_item.product_id', '=', 'sales_stock.product_id');
             $join->on('sales_order_item.order_id', '=', 'sales_stock.order_id');  
       })->where('sales_order_item.delivery_from','=','Supplier')
        ->select('sales_order_item.*', 'sales_stock.qty as outofstockqty','add_to_bag.qty as inbagqty')->where('sales_order_item.order_id',$id)->orderBy('sales_order_item.item_id','DESC')->get();
        
        $current_status = DB::table('order_statuses')
    ->Join('sales_order_item','order_statuses.id','=','sales_order_item.order_status_id')
    ->where('sales_order_item.order_id',$id)
    ->where('sales_order_item.delivery_from','=','Supplier')
    ->select('order_statuses.status')
    ->first();
    }
    
    $productIDD =array();
    foreach($getorder as $productID1){
        array_push($productIDD,$productID1->item_id);
    }
    
    $productIDD1 =array();
    foreach($getorder as $productID11){
        array_push($productIDD1,$productID11->product_id);
    }
    
    $productQty =array();
    foreach($getorder as $productQty1){
        array_push($productQty,$productQty1->qty_ordered);
    }

    // print_r($productIDD);exit;
    // $productIDD = json_decode(json_encode($productID), true);
    
    
    // $newproduct=DB::table('catalog_product_entity_varchar')
    // ->join('catalog_product_index_price', 'catalog_product_index_price.entity_id', '=', 'catalog_product_entity_varchar.entity_id')
    //  ->select('catalog_product_entity_varchar.value', 'catalog_product_entity_varchar.entity_id', 'catalog_product_index_price.final_price')
    // ->where('catalog_product_entity_varchar.attribute_id','73')
    // ->where('catalog_product_entity_varchar.store_id','0')
    // ->distinct('catalog_product_entity_varchar.value')
    // ->where('catalog_product_index_price.customer_group_id','0')->get();
    $newproduct = [];
    
    // $catproduct=[];
    // for($i=0;$i<=count($newproduct);$i++){
      
    //     $finalprice=DB::table('catalog_product_index_price')->where('customer_group_id','0')->where('entity_id',$newproduct[$i]->entity_id)->first();

    //     $product_cat =new stdClass();
    //     $product_cat->price =isset($finalprice->final_price)? $finalprice->final_price:"0"; 
    //     $product_cat->productid = $newproduct[$i]->entity_id; 
    //     $product_cat->count = "1"; 
    //     $product_cat->name = $newproduct[$i]->value;
         
    //     $catproduct[]=$product_cat;
    // }
    
    $strid = isset($order->productOrders['0']->store_id)? $order->productOrders['0']->store_id : "";
      $getstore = DB::table('store')->where('store_id',$strid)->first();
       
        if($getstore){
           $getstorename=$getstore->name;
        }
         else{
               $getstorename="";
         }
     $update = strtotime($order->updated_at);
         $delivery = strtotime($order->created_at);
        $getzone=date_default_timezone_get();
        
          date_default_timezone_set($getzone);
          $created_at=date("Y-m-d", $update);
         $updated_at=date("Y-d-m T G:i", $update);
         
         $paym=json_decode($getpaystatus->additional_information);
         
         $method=isset($getpaystatus->method) ? $getpaystatus->method  : '';
       
         if($paym->method_title=="DebitCard | CreditCard"){
            $pay="Card Payment"; 
         }else{
             $pay=$paym->method_title;
         }
         $pay=$paym->method_title;
       //print_r($order);
//       $getorder[0]->sub_status;
        $paymethodd = DB::table('sales_order_payment')->where('parent_id',$id)->select('method')->first();
        $paymethod = isset($paymethodd->method)? $paymethodd->method : '';
        
        $sales_order_item_configurable = DB::select("SELECT soi.sku FROM sales_order_item as soi WHERE soi.order_id='$id' AND soi.product_type='Configurable'");
        // print_r($sales_order_item_configurable);exit;
        
        $storeeIDD = isset($order->productOrders['0']->store_id)? $order->productOrders['0']->store_id : "57";
        
        //Sub Status Check Start
            $currentMainStatus1 = DB::select("SELECT status FROM sales_order WHERE entity_id='$id'");
            $currentMainStatus = isset($currentMainStatus1[0]->status)? $currentMainStatus1[0]->status : "";
            $resulltts=DB::select("SELECT sub_status FROM sales_order_item WHERE order_id='$id' and product_type='simple' and delivery_from='$productType'");
            $aar = array();
            foreach($resulltts as $resultss1){
                if(empty($resultss1->sub_status) || is_null($resultss1->sub_status)){
                        $subStatus='';
                        if($currentMainStatus == "processing"){
                                $subStatus = $currentMainStatus;
                        }else{
                                $subStatus = "Order Placed";
                        }
                        array_push($aar, $subStatus);
                }else{
                        array_push($aar, $resultss1->sub_status);
                }
            }
            // print_r($aar);
            $subStatusArrayCount = array_count_values($aar);
            
            $stCheck = '';
            if(($currentMainStatus == 'pending') || ($currentMainStatus == 'canceled')){
                $stCheck = $currentMainStatus;
            }else{
                if(count($subStatusArrayCount)>1){
                    foreach($subStatusArrayCount as $key=>$subStatusArrayCount1){
                        if($key != "canceled"){
                            $stCheck = $key;
                        }
                    }
                }else{
                    $stCheck = key($subStatusArrayCount);
                }
            }
        //Sub Status Check End
        
        $cusmId1 = DB::table('sales_order')->where('entity_id',$id)->first();
        $cusmId = isset($cusmId1->customer_id)? $cusmId1->customer_id : "";
        $customersigninphone1 = DB::table('customer_entity_varchar')->where('entity_id',$cusmId)->first();
        $customersigninphone = isset($customersigninphone1->value)? $customersigninphone1->value : "-";
        
        $getbagqtty = isset($getbag['0']->qty)? $getbag['0']->qty : "";
        return view('orders.edit', ["sales_order_item_configurable"=>$sales_order_item_configurable, "storeeIDD"=>$storeeIDD])->with('id', $id)->with('paymethod', $paymethod)->with('getbag', $getbagqtty)->with('order', $order)->with("customFields", isset($html) ? $html : false)->with("user", $user)->with("driver",$driver)->with("getorder", $getorder)->with("picker",$picker)->with("orderStatus", $orderStatus)->with("getaddress", $getaddress)->with("getaddress1", $getaddress1)->with("getpaystatus", $pay)->with("payment_method",$method)->with( "subtotal",$order['base_subtotal'])->with("taxAmount",$taxAmount)->with("total",$order['base_grand_total'])->with("catproduct",$newproduct)->with("storename",$getstorename)->with("updated_at",$updated_at)->with("created_at",$created_at)->with("newadd",$orderpicker->action_required)->with("orderStatusess",$current_status->status)->with("productID", $productIDD)->with("productIDD", $productIDD1)->with("productQty", $productQty)->with("stCheck", $stCheck)->with('paayymethod', $paymethod)->with("customersigninphone",$customersigninphone)->with('customerId1',$cusmId)->with('orderId', $id);
    }


 public function orderedit($id)
    {
        
        $this->orderRepository->pushCriteria(new OrdersOfUserCriteria(auth()->id()));
        $order = $this->OrderitemRepository->findWithoutFail($id);
        if (empty($order)) {
            // Flash::error(__('lang.not_found', ['operator' => __('lang.order')]));

            // return redirect(route('orders.index'));
        }

       // $market = $order->productOrders()->first();
        $market = isset($market) ? $market->product['market_id'] : 0; 

        $user = $this->userRepository->getByCriteria(new ClientsCriteria())->pluck('name', 'id');
        // $driver = $this->userRepository->getByCriteria(new DriversCriteria($market))->pluck('name', 'id');
        // $picker = $this->userRepository->getByCriteria(new PickerCriteria($market))->pluck('name', 'id');
        $orderStatus = $this->orderStatusRepository->pluck('status', 'id');

       $customFieldsValues = "";
        $customFields = "";
        $hasCustomField = "";
        if ($hasCustomField) {
            $html = generateCustomField($customFields, $customFieldsValues);
        }
        $type=isset($_GET['type']) ? $_GET['type'] : ''; 
        $getorder = DB::table('sales_order_item')->where('order_id',$id)->where('delivery_from',$type)->first();
        $driver_id=$getorder->driver_id; 
        $picker_id=$getorder->picker_id; 
        if($type=="Grocery"){
        $picker = DB::table('users')->where('role_id','=','picker')->get();
        $driver = DB::table('users')->where('role_id','=','driver')->get();
        }else if($type=="Supplier"){ 
         $picker = DB::table('users')->where('role_id','=','supplierpicker')->get();
        $driver = DB::table('users')->where('role_id','=','supplierdriver')->get();    
        }else{
        $picker = DB::table('users')->where('role_id','=','materialpicker')->get();
        $driver = DB::table('users')->where('role_id','=','materialdriver')->get();      
        }
        return view('orders.orderedit')->with('order', $order)->with("customFields", isset($html) ? $html : false)->with("user", $user)->with("driver", $driver)->with("getorder", $getorder)->with("getpicker_id",$picker_id)->with("getdriver_id",$driver_id)->with("picker",$picker)->with("orderStatus", $orderStatus)->with('entity_id',$id);
    }

    /**
     * Update the specified Order in storage.
     *
     * @param int $id
     * @param UpdateOrderRequest $request
     *
     * @return Response
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function update($id, UpdateOrderRequest $request)
    {
      
        $this->orderRepository->pushCriteria(new OrdersOfUserCriteria(auth()->id()));
        $oldOrder = $this->orderRepository->findWithoutFail($id);
        if (empty($oldOrder)) {
            Flash::error(__('lang.not_found', ['operator' => __('lang.order')]));
            return redirect(route('orders.index'));
        }
      
        //$oldStatus = $oldOrder->payment->status;
        $input = $request->all();
        $customFields = $this->customFieldRepository->findByField('custom_field_model', $this->orderRepository->model());
        try {

            $order = $this->orderRepository->update($input, $id);

            // if (setting('enable_notifications', false)) {
            //     if (isset($input['order_status_id']) && $input['order_status_id'] != $oldOrder->order_status_id) {
            //         Notification::send([$order->user], new StatusChangedOrder($order));
            //     }

            //     if (isset($input['driver_id']) && ($input['driver_id'] != $oldOrder['driver_id'])) {
            //         $driver = $this->userRepository->findWithoutFail($input['driver_id']);
            //         if (!empty($driver)) {
            //             Notification::send([$driver], new AssignedOrder($order));
            //         }
            //     }
            // }

            // $this->paymentRepository->update([
            //     "status" => $input['status'],
            // ], $order['payment_id']);
            //dd($input['status']);

            //event(new OrderChangedEvent($oldStatus, $order));

            foreach (getCustomFieldsValues($customFields, $request) as $value) {
                $order->customFieldsValues()
                    ->updateOrCreate(['custom_field_id' => $value['custom_field_id']], $value);
            }
        } catch (ValidatorException $e) {
            Flash::error($e->getMessage());
        }

        Flash::success(__('lang.updated_successfully', ['operator' => __('lang.order')]));

        return redirect(route('orders.index'));
    }
 public function orderupdate($id, Request $request)
    {
    
  $input=$request->all();
   $type=$input['type'];      
     $orderid=DB::table('sales_order')
        ->where('entity_id', $id)->first() ;
        $backid=$id;
    //   DB::table('sales_order')
    //     ->where('entity_id','=',$id) 
    //     ->update([
    //       'driver_id' => $input['driver_id'],
    //       'picker_id' => $input['picker_id'] ,
          
    //     ]);
    if($type=="Grocery"){
         DB::table('sales_order_item')
        ->where('order_id','=',$id) 
         ->where('delivery_from','=',$type) 
        ->update([
           'driver_id' => $input['driver_id'],
           'picker_id' => $input['picker_id'] ,
          
        ]);
    }else if($type=="Warehouse"){
       DB::table('sales_order_item')
        ->where('order_id','=',$id) 
         ->where('delivery_from','=',$type) 
        ->update([
           'driver_id' => $input['driver_id'],
           'picker_id' => $input['picker_id'] ,
          
        ]);
    } else if($type=="Supplier"){
       DB::table('sales_order_item')
        ->where('order_id','=',$id) 
         ->where('delivery_from','=',$type) 
        ->update([
           'driver_id' => $input['driver_id'],
           'picker_id' => $input['picker_id'] ,
          
        ]);
    }
         Flash::success(__('lang.updated_successfully', ['operator' => __('lang.order')]));
        //   return redirect('orders/'.$backid.'/edit');
        return redirect()->back();
    }
    /**
     * Remove the specified Order from storage.
     *
     * @param int $id
     *
     * @return Response
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function destroy($id)
    {
        if (!env('APP_DEMO', false)) {
            $this->orderRepository->pushCriteria(new OrdersOfUserCriteria(auth()->id()));
            $order = $this->orderRepository->findWithoutFail($id);

            if (empty($order)) {
                Flash::error(__('lang.not_found', ['operator' => __('lang.order')]));

                return redirect(route('orders.index'));
            }

            $this->orderRepository->delete($id);

            Flash::success(__('lang.deleted_successfully', ['operator' => __('lang.order')]));


        } else {
            Flash::warning('This is only demo app you can\'t change this section ');
        }
        return redirect(route('orders.index'));
    }
     public function orderdestroy($id)
    {
        if (!env('APP_DEMO', false)) {
            $this->orderRepository->pushCriteria(new OrdersOfUserCriteria(auth()->id()));
            $order = $this->orderRepository->findWithoutFail($id);

            if (empty($order)) {
                Flash::error(__('lang.not_found', ['operator' => __('lang.order')]));

                return redirect(route('orders.index'));
            }

          //  $this->orderRepository->delete($id);
            $result = DB::table('sales_order_item')->where('item_id','=',$id)->delete();
            // Flash::success(__('lang.deleted_successfully', ['operator' => __('lang.order')]));
            
             if($result){
                Flash::success(__('lang.deleted_successfully', ['operator' => __('lang.order')]));
                return redirect()->back();
            }


        } else {
            Flash::warning('This is only demo app you can\'t change this section ');
        }
       // return redirect(route('orders.index'));
    }

    /**
     * Remove Media of Order
     * @param Request $request
     */
    public function removeMedia(Request $request)
    {
        $input = $request->all();
        $order = $this->orderRepository->findWithoutFail($input['id']);
        try {
            if ($order->hasMedia($input['collection'])) {
                $order->getFirstMedia($input['collection'])->delete();
            }
        } catch (\Exception $e) {
            Log::error($e->getMessage());
        }
    }
    
    public function orderUpdateQuantity(Request $request){
         $input = $request->all();
        
         return $input;
    }
     
    public function deleteitem(Request $request){
        $itemId =58; 
        print_r($itemId);die;
        try{
            $this->orderItemRepository->deleteById($itemId);
        } catch (Exception $exception) {
            $this->logger->error($exception->getMessage());
        }
     
    }
    public function orderpickinglist($id){
        $sales_order = DB::table('sales_order')->where('entity_id',$id)->orderBy('entity_id','DESC')->get();
         $product_type = isset($_GET["product_type"])? $_GET["product_type"] : "";
         return view('orders/pickinglist', ['entity_id' => $id, "product_type" => $product_type]);
    }
}
