<?php
namespace App\Http\Controllers;

use Flash;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Response;
use Prettus\Validator\Exceptions\ValidatorException;
use DB;

class PaymentSetupController extends Controller
{
    public function index()
    {
         $payment_setup = DB::table('payment_setup')->orderBy('id','DESC')->paginate(10);
         return view('payment/index', ['payment_setup' => $payment_setup
      ]);
    }
    
    /**
     * Show the form for creating a new User.
     *
     * @return Response
     */
    public function create()
    {
        return view('payment.create');
    }

    /**
     * Store a newly created User in storage.
     *
     * @param CreateUserRequest $request
     *
     * @return Response
     */
    public function store(Request $request)
    {
        if (env('APP_DEMO', false)) {
            Flash::warning('This is only demo app you can\'t change this section ');
            return redirect(route('users.index'));
        }
        try {
      $date_added=date('Y-m-d H:i:s');
      DB::table('payment_setup')->insert(['cutoff_amount'=>$request->cutoff_amount,'type'=>$request->type,'amount_type'=>$request->amount_type,'amount'=>$request->amount,'status'=>$request->status,'created'=>$date_added]);
        } catch (ValidatorException $e) {
            Flash::error($e->getMessage());
        }

        Flash::success('saved successfully.');
        return redirect(route('payment.index'));
    }

    /**
     * Display the specified User.
     *
     * @param int $id
     *
     * @return Response
     */
    public function show($id)
    {
        $user = $this->VehicleRepository->findWithoutFail($id);

        if (empty($user)) {
            Flash::error('User not found');
            return redirect(route('tolerance.index'));
        }

        return view('settings.users.profile')->with('user', $user);
    }
    /**
     * Show the form for editing the specified User.
     *
     * @param int $id
     *
     * @return Response
     */
   
    
      public function edit($id)
    {
        if (!auth()->user()->hasRole('admin') && $id != auth()->id()) {
            Flash::error('Permission denied');
            return redirect(route('payment.index'));
        }
       
	    $result = array();		
		$result['message'] = array();
		
		$editsetup= DB::table('payment_setup')->where('id','=',$id)->get();
		$result['editsetup'] = $editsetup;		
		
        if (empty($editsetup)) {
            Flash::error('Payment Setup not found');
            return redirect(route('payment.index'));
        }
        
        return view("payment.edit",['editsetup' => $editsetup])->with('result',$result);
    }

    /**
     * Update the specified User in storage.
     *
     * @param int $id
     * @param UpdateUserRequest $request
     *
     * @return Response
     */
    public function update($id,Request $request)
    {
        if (env('APP_DEMO', false)) {
            Flash::warning('This is only demo app you can\'t change this section ');
            return redirect(route('users.profile'));
        }
        if (!auth()->user()->hasRole('admin') && $id != auth()->id()) {
            Flash::error('Permission denied');
            return redirect(route('users.profile'));
        }

        $langtype = DB::table('payment_setup')->where('id','=',$request->id)->get();
        if (empty($langtype)) {
            Flash::error('label not found');
            return redirect(route('users.profile'));
        }
        try {
        $last_modified=date('Y-m-d H:i:s');
		DB::table('payment_setup')->where('id','=',$id)->update(['cutoff_amount'=>$request->cutoff_amount,'type'=>$request->type,'amount_type'=>$request->amount_type,'amount'=>$request->amount,'status'=>$request->status,'modified'=>$last_modified]);
        } catch (ValidatorException $e) {
            Flash::error($e->getMessage());
        }

        Flash::success('Payment setup updated successfully.');

        return redirect()->back();
    }

    /**
     * Remove the specified User from storage.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy($id)
    {
        if (env('APP_DEMO', false)) {
            Flash::warning('This is only demo app you can\'t change this section ');
            return redirect(route('users.index'));
        }
        
        $payment_setup=DB::table('payment_setup')->where('id','=',$id)->get();
		
        if (empty($payment_setup)) {
            Flash::error('Payment Setup not found');
            return redirect(route('payment.index'));
        }

        DB::table('payment_setup')->where('id','=',$id)->delete();

        Flash::success('Payment Setup deleted successfully.');

        return redirect(route('payment.index'));
    }

    /**
     * Remove Media of User
     * @param Request $request
     */
    public function removeMedia(Request $request)
    {
        if (env('APP_DEMO', false)) {
            Flash::warning('This is only demo app you can\'t change this section ');
        } else {
            if (auth()->user()->can('medias.delete')) {
                $input = $request->all();
                $user = $this->VehicleRepository->findWithoutFail($input['id']);
                try {
                    if ($user->hasMedia($input['collection'])) {
                        $user->getFirstMedia($input['collection'])->delete();
                    }
                } catch (\Exception $e) {
                    Log::error($e->getMessage());
                }
            }
        }
    }
}
