<?php

namespace App\Http\Controllers;

use App\Repositories\OrderRepository;
use App\Repositories\PaymentRepository;
use App\Repositories\MarketRepository;
use App\Repositories\UserRepository;
use Illuminate\Http\Request;
use DB;
use Carbon\Carbon;
use Illuminate\Pagination\Paginator;
use Illuminate\Support\Collection;
use Illuminate\Pagination\LengthAwarePaginator;
use \stdClass;

class ReportPaymentController extends Controller
{
    
    /** @var  OrderRepository */
    private $orderRepository;


    /**
     * @var UserRepository
     */
    private $userRepository;

    /** @var  MarketRepository */
    private $marketRepository;
    /** @var  PaymentRepository */
    private $paymentRepository;

    public function __construct(OrderRepository $orderRepo, UserRepository $userRepo, PaymentRepository $paymentRepo, MarketRepository $marketRepo)
    {
        parent::__construct();
        $this->orderRepository = $orderRepo;
        $this->userRepository = $userRepo;
        $this->marketRepository = $marketRepo;
        $this->paymentRepository = $paymentRepo;
    }
    
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $date = Carbon::now();
        // $ordersCount = $this->orderRepository->count();
        $membersCount = $this->userRepository->count();
        $marketsCount = $this->marketRepository->count();
        $order_id_value = "";
        if(isset($_GET["from_date"]) && isset($_GET["to_date"]) && isset($_GET["payment_method"])){
            $from_date = isset($_GET["from_date"])? $_GET["from_date"] : '';
            $to_date = isset($_GET["to_date"])? $_GET["to_date"] : '';
            $payment_method = isset($_GET["payment_method"])? $_GET["payment_method"] : '';
            $order_id_value = DB::select("SELECT DISTINCT sales_order.picker_id, sales_order.driver_id, sales_order.base_grand_total, sales_order.increment_id, sales_order_item.order_id, sales_order_item.delivery_dates, sales_order_payment.method FROM sales_order INNER JOIN sales_order_item on sales_order_item.order_id=sales_order.entity_id INNER JOIN sales_order_payment on sales_order_payment.entity_id=sales_order.entity_id WHERE sales_order_item.delivery_dates BETWEEN '$from_date' and '$to_date' AND sales_order_payment.method='$payment_method' AND sales_order.status NOT IN('payment_review','canceled','closed') ORDER BY sales_order_item.order_id DESC");
        } else {
            $order_id_value = DB::select("SELECT DISTINCT sales_order.picker_id, sales_order.driver_id, sales_order.base_grand_total, sales_order.increment_id, sales_order_item.order_id, sales_order_item.delivery_dates, sales_order_payment.method FROM sales_order INNER JOIN sales_order_item on sales_order_item.order_id=sales_order.entity_id INNER JOIN sales_order_payment on sales_order_payment.entity_id=sales_order.entity_id WHERE sales_order_item.delivery_dates=CURRENT_DATE AND sales_order.status NOT IN('payment_review','canceled','closed') ORDER BY sales_order_item.order_id DESC");
        }
            $salesorder=[];
           $notification = DB::table('notification_alert')->where('created_at',$date->toDateString())->get();
          for($i=0;$i<count($order_id_value);$i++){
            
              $sales = new stdClass; 
			  $drivers= DB::table('users')->where('id',$order_id_value[$i]->driver_id)->first();
	
			  $pickers= DB::table('users')->where('id',$order_id_value[$i]->picker_id)->first();
			  $sales->order_id = isset($order_id_value[$i]->order_id)?$order_id_value[$i]->order_id:"0";
			 $sales->increment_id=$order_id_value[$i]->increment_id;
			 $sales->method=$order_id_value[$i]->method;
			 $sales->base_grand_total=$order_id_value[$i]->base_grand_total;
              $sales->drivername = isset($drivers->name)?$drivers->name:"-";
              $sales->pickername =isset($pickers->name)?$pickers->name:"-";
            $sales->dates =$order_id_value[$i]->delivery_dates;
             $salesorder[]=$sales;
            
          }
          $perPage = 10;
          $data = $this->paginate($salesorder, $perPage);
         return view('reports_payment.index', ['orderDetails' => $data, "perPage" => $perPage
      ]);
    }
    
    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    public function paginate($items, $perPage, $page = null, $options = [])
    {
        $page = $page ?: (Paginator::resolveCurrentPage() ?: 1);
        $items = $items instanceof Collection ? $items : Collection::make($items);
        $pagePath = "";
        $url = parse_url($_SERVER['REQUEST_URI'], PHP_URL_PATH);
        if(isset($_GET["from_date"]) && isset($_GET["to_date"]) && isset($_GET["payment_method"])){
           $fullUrl = $url."?from_date=".$_GET["from_date"]."&to_date=".$_GET["to_date"]."&payment_method=".$_GET["payment_method"];
           $pagePath = ['path' => $fullUrl];
        } else {
            $pagePath = ['path' => $url];
        }
        return new LengthAwarePaginator($items->forPage($page, $perPage), $items->count(), $perPage, $page, $pagePath, $options);
    }
    
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
