<?php
namespace App\Http\Controllers;

use App\DataTables\UserDataTable;
use App\Events\UserRoleChangedEvent;
use App\Http\Requests\CreateUserRequest;
use App\Http\Requests\UpdateUserRequest;
use App\Repositories\CustomFieldRepository;
use App\Repositories\RoleRepository;
use App\Repositories\UploadRepository;
use App\Repositories\UserRepository;
use Flash;
use DB;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Response;
use Prettus\Validator\Exceptions\ValidatorException;

class UserController extends Controller
{
    /** @var  UserRepository */
    private $userRepository;
    /**
     * @var RoleRepository
     */
    private $roleRepository;

    private $uploadRepository;

    /**
     * @var CustomFieldRepository
     */
    private $customFieldRepository;

    public function __construct(UserRepository $userRepo, RoleRepository $roleRepo, UploadRepository $uploadRepo,
                                CustomFieldRepository $customFieldRepo)
    {
        parent::__construct();
        $this->userRepository = $userRepo;
        $this->roleRepository = $roleRepo;
        $this->uploadRepository = $uploadRepo;
        $this->customFieldRepository = $customFieldRepo;
    }
    public function country(){
         $domain_address_code = session('domain_address_setup');
         if(empty($domain_address_code)){
            $domain_address_code='JO';
         }
         $sqlcountry=DB::select("SELECT value,GROUP_CONCAT(scope_id SEPARATOR ',') AS `store_id`  FROM `core_config_data` WHERE path='general/country/destinations' AND value='$domain_address_code' group by value order by config_id asc"); 
         $countryy  = array();
         $s1 = 0;
         foreach($sqlcountry as $country){
            $explode1=explode(',',$country->store_id);
            $countrycode=$country->value;
            $store_id1=isset($explode1[0]) ? $explode1[0] :'';
            $stores1=DB::select("SELECT code FROM store WHERE store_id='$store_id1'");
            $codeurl=isset($stores1[0]->code) ? $stores1[0]->code : '';
            $msp_tfa_country_codes=DB::select("SELECT name FROM msp_tfa_country_codes WHERE code='$countrycode'");
            $countryname=isset($msp_tfa_country_codes[0]->name) ? $msp_tfa_country_codes[0]->name : '';
            $countryy[$s1]['country_name'] = $countryname;
            $countryy[$s1]['country_code'] = $countrycode;
            $s1++;
        }
        return $countryy;
    }
    /**
     * Display a listing of the User.
     *
     * @param UserDataTable $userDataTable
     * @return Response
     */
    public function index(UserDataTable $userDataTable)
    {
        return $userDataTable->render('settings.users.index');
    }

    /**
     * Display a user profile.
     *
     * @param
     * @return Response
     */
    public function profile()
    {
        $user = $this->userRepository->findWithoutFail(auth()->id());
        unset($user->password);
        $customFields = false;
        $role = $this->roleRepository->pluck('name', 'name');
        $rolesSelected = $user->getRoleNames()->toArray();
        $customFieldsValues = $user->customFieldsValues()->with('customField')->get();
        //dd($customFieldsValues);
        $hasCustomField = in_array($this->userRepository->model(), setting('custom_field_models', []));
        if ($hasCustomField) {
            $customFields = $this->customFieldRepository->findByField('custom_field_model', $this->userRepository->model());
            $customFields = generateCustomField($customFields, $customFieldsValues);
        }
        $countryy = $this->country();
        $country_code = $countryy[0]['country_code'];
        $store = DB::table('store_group')->where('group_id','!=','0')->get();
        $uid = auth()->id();
        $userTable=DB::select("SELECT * FROM users WHERE id = $uid and country=\"$country_code\"");
        return view('settings.users.profile', compact(['user', 'role', 'rolesSelected', 'customFields', 'customFieldsValues','store', 'userTable']))->with('country', $countryy);
    }

    /**
     * Show the form for creating a new User.
     *
     * @return Response
     */
    public function create()
    {
        $role = $this->roleRepository->pluck('name', 'name');

        $rolesSelected = [];
        $hasCustomField = in_array($this->userRepository->model(), setting('custom_field_models', []));
     
        if ($hasCustomField) {
            $customFields = $this->customFieldRepository->findByField('custom_field_model', $this->userRepository->model());
            
            $html = generateCustomField($customFields);
             
        }
         $countryy = $this->country();
         $country_code = $countryy[0]['country_code'];
         $store = DB::table('store_group')->where('group_id','!=','0')->get();
         $user = $this->userRepository->findWithoutFail(auth()->id());
         $userTable=DB::select("SELECT * FROM users WHERE country=\"$country_code\"");
        return view('settings.users.create')
            ->with("role", $role)
            ->with("customFields", isset($html) ? $html : false)
            ->with("rolesSelected", $rolesSelected)
            ->with('store', $store)
            ->with('user', $user)
            ->with('userTable', $userTable)
            ->with('country', $countryy);
    }

    /**
     * Store a newly created User in storage.
     *
     * @param CreateUserRequest $request
     *
     * @return Response
     */
    public function store(Request $request)
    {
        if (env('APP_DEMO', false)) {
            Flash::warning('This is only demo app you can\'t change this section ');
            return redirect(route('users.index'));
        }

        $input = $request->all();
        
        $customFields = $this->customFieldRepository->findByField('custom_field_model', $this->userRepository->model());
      
        //$input['roles'] = isset($input['roles']) ? $input['roles'] : [];
        $input['password'] = Hash::make($input['password']);
        $input['api_token'] = str_random(60);
        $input['roles']=$input['roles'][0];
        $input['store_id']=$input['store_id'];
        $input['country']=$input['country'];
        try {
            $user = $this->userRepository->create($input);
            $user->syncRoles($input['roles']);
            $user->customFieldsValues()->createMany(getCustomFieldsValues($customFields, $request));
              
            if (isset($input['avatar']) && $input['avatar']) {
                $cacheUpload = $this->uploadRepository->getByUuid($input['avatar']);
                $mediaItem = $cacheUpload->getMedia('avatar')->first();
                $mediaItem->copy($user, 'avatar');
            }
            event(new UserRoleChangedEvent($user));
            $users1 = DB::table('users')->orderBy('id','DESC')->get();
            $user_id=isset($users1[0]->id) ? $users1[0]->id : ''; 
            $implodestoreid = implode(', ', $input['store_id']);
            $role_name=$input['roles'];
            $roles = DB::table('roles')->where('name','=',$role_name)->get();
            $role_type=isset($roles[0]->role_type) ? $roles[0]->role_type : ''; 
            DB::table('users')->where('id','=',$user_id)->update(['role_id'=>$input['roles'],'role_type'=>$role_type,'store_id'=>$implodestoreid, 'country'=>$input['country']]);
        } catch (ValidatorException $e) {
            Flash::error($e->getMessage());
        }

        Flash::success('saved successfully.');

        return redirect(route('users.index'));
    }

    /**
     * Display the specified User.
     *
     * @param int $id
     *
     * @return Response
     */
    public function show($id)
    {
        $user = $this->userRepository->findWithoutFail($id);

        if (empty($user)) {
            Flash::error('User not found');

            return redirect(route('users.index'));
        }

        return view('settings.users.profile')->with('user', $user);
    }

    public function loginAsUser(Request $request, $id)
    {
        $user = $this->userRepository->findWithoutFail($id);
        if (empty($user)) {
            Flash::error('User not found');
            return redirect(route('users.index'));
        }
        auth()->login($user, true);
        if (auth()->id() !== $user->id) {
            Flash::error('User not found');
        }
        return redirect(route('users.profile'));
    }

    /**
     * Show the form for editing the specified User.
     *
     * @param int $id
     *
     * @return Response
     */
    public function edit($id)
    {
        if (!auth()->user()->hasRole('admin') && $id != auth()->id()) {
            Flash::error('Permission denied');
            return redirect(route('users.index'));
        }
        $countryy = $this->country();
        $country_code = $countryy[0]['country_code'];
        $user = $this->userRepository->findWithoutFail($id);
     
      $rolesSelected[]=$user->role_id;
        unset($user->password);
        $html = false;
        $role = $this->roleRepository->pluck('name', 'name');
        $store = DB::table('store_group')->where('group_id','!=','0')->get();
	    $storeSelected=$user->store_id;
		
       // $rolesSelected = $user->getRoleNames()->toArray();
      
       
        $customFieldsValues = $user->customFieldsValues()->with('customField')->get();
        $customFields = $this->customFieldRepository->findByField('custom_field_model', $this->userRepository->model());
        $hasCustomField = in_array($this->userRepository->model(), setting('custom_field_models', []));
        if ($hasCustomField) {
            $html = generateCustomField($customFields, $customFieldsValues);
        }

        if (empty($user)) {
            Flash::error('User not found');

            return redirect(route('users.index'));
        }
        $userTable=DB::select("SELECT * FROM users WHERE id = $id and country=\"$country_code\"");
        return view('settings.users.edit')
            ->with('user', $user)
            ->with("role", $role)
            ->with("rolesSelected", $rolesSelected)
            ->with("customFields", $html)
            ->with("store", $store)
            ->with("storeSelected", $storeSelected)
            ->with('userTable', $userTable)
            ->with('country', $countryy);
            
    }

    /**
     * Update the specified User in storage.
     *
     * @param int $id
     * @param UpdateUserRequest $request
     *
     * @return Response
     */
    public function update($id, Request $request)
    {
        if (env('APP_DEMO', false)) {
            Flash::warning('This is only demo app you can\'t change this section ');
            return redirect(route('users.profile'));
        }
      
        
        $user = $this->userRepository->findWithoutFail($id);
     

        if (empty($user)) {
            Flash::error('User not found');
            return redirect(route('users.profile'));
        }
        $customFields = $this->customFieldRepository->findByField('custom_field_model', $this->userRepository->model());

        $input = $request->all();
        
       // DB::table('users')->where('role_id','picker')->get;
            $input['roles']=$input['roles'][0];
            $input['roles'] = isset($input['roles']) ? $input['roles'] : []; 
            $implodestoreid = implode(', ', $input['store_id']);
            $role_name=$input['roles'];
            $roles = DB::table('roles')->where('name','=',$role_name)->get();
            $role_type=isset($roles[0]->role_type) ? $roles[0]->role_type : ''; 
            DB::table('users')->where('id','=',$id)->update(['role_id'=>$input['roles'],'role_type'=>$role_type,'store_id'=>$implodestoreid, 'country'=>$input['country']]);
        
        if (empty($input['password'])) {
            unset($input['password']);
        } else {
            $input['password'] = Hash::make($input['password']);
        }
        try {
           
            $user = $this->userRepository->update($input, $id);
            
            if (empty($user)) {
                Flash::error('User not found');
                return redirect(route('users.profile'));
            }
            if (isset($input['avatar']) && $input['avatar']) {
                $cacheUpload = $this->uploadRepository->getByUuid($input['avatar']);
                $mediaItem = $cacheUpload->getMedia('avatar')->first();
                $mediaItem->copy($user, 'avatar');
            }
          
            foreach (getCustomFieldsValues($customFields, $request) as $value) {
                $user->customFieldsValues()
                    ->updateOrCreate(['custom_field_id' => $value['custom_field_id']], $value);
            }
            
            event(new UserRoleChangedEvent($user));
        
             if($input['roles']!="driver"){
            
              $getdriver=DB::table('drivers')->where('user_id',$id)->get();
                
              if($getdriver){
                  
                    $deldriver=DB::table('drivers')->where('user_id','=',$id)->delete();
              
               
              }
           }
        } catch (ValidatorException $e) {
            Flash::error($e->getMessage());
        }


        Flash::success('User updated successfully.');

         return redirect(route('users.index'));

    }

    /**
     * Remove the specified User from storage.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy($id)
    {
        if (env('APP_DEMO', false)) {
            Flash::warning('This is only demo app you can\'t change this section ');
            return redirect(route('users.index'));
        }
        $user = $this->userRepository->findWithoutFail($id);

        if (empty($user)) {
            Flash::error('User not found');

            return redirect(route('users.index'));
        }

        $this->userRepository->delete($id);

        Flash::success('User deleted successfully.');

        return redirect(route('users.index'));
    }

    /**
     * Remove Media of User
     * @param Request $request
     */
    public function removeMedia(Request $request)
    {
        if (env('APP_DEMO', false)) {
            Flash::warning('This is only demo app you can\'t change this section ');
        } else {
            if (auth()->user()->can('medias.delete')) {
                $input = $request->all();
                $user = $this->userRepository->findWithoutFail($input['id']);
                try {
                    if ($user->hasMedia($input['collection'])) {
                        $user->getFirstMedia($input['collection'])->delete();
                    }
                } catch (\Exception $e) {
                    Log::error($e->getMessage());
                }
            }
        }
    }
}
