<?php

namespace App\Models;

use Eloquent as Model;

/**
 * Class Order
 * @package App\Models
 * @version August 31, 2019, 11:11 am UTC
 *
 * @property \App\Models\User user
 * @property \App\Models\DeliveryAddress deliveryAddress
 * @property \App\Models\Payment payment
 * @property \App\Models\OrderStatus orderStatus
 * @property \App\Models\ProductOrder[] productOrders
 * @property integer user_id
 * @property integer order_status_id
 * @property integer payment_id
 * @property double tax
 * @property double delivery_fee
 * @property string id
 * @property int delivery_address_id
 * @property string hint
 * @property integer picker_id
 */
 use DB;
class Order extends Model
{

    protected $primaryKey = 'entity_id';
    public $table = 'sales_order';
    
    public $fillable = [
        'entity_id',
        'store_id',
        'customer_id',
        'base_grand_total',
        'created_at',
        'total_qty_ordered',
        'order_currency_code',
        'status',
        'driver_id',
        'order_status_id',
        'picker_id',
        'inbagqty',
    ];

    /**
     * The attributes that should be casted to native types.
     *
     * @var array
     */
    protected $casts = [
        'entity_id' => 'integer',
        'store_id' => 'integer',
        'customer_id' => 'integer',
        'base_grand_total' => 'string',
        'created_at' => 'string',
        'total_qty_ordered' => 'string',
        'order_currency_code' => 'string',
        'status'=>'string',
        'driver_id' => 'integer',
        'order_status_id' => 'integer',
        'picker_id'=> 'integer',
        'inbagqty'=>'integer'
    ];

    /**
     * Validation rules
     *
     * @var array
     */
    public static $rules = [
        // 'user_id' => 'required|exists:users,id',
        // 'order_status_id' => 'required|exists:order_statuses,id',
        // 'payment_id' => 'exists:payments,id',
        // 'driver_id' => 'nullable|exists:users,id',
    ];

    /**
     * New Attributes
     *
     * @var array
     */
    protected $appends = [
        'custom_fields',
        
    ];

    public function customFieldsValues()
    {
          
        return $this->morphMany('App\Models\CustomFieldValue', 'customizable');
    }

    public function getCustomFieldsAttribute()
    {
        $hasCustomField = in_array(static::class,setting('custom_field_models',[]));
        if (!$hasCustomField){
            return [];
        }
        $array = $this->customFieldsValues()
            ->join('custom_fields','custom_fields.id','=','custom_field_values.custom_field_id')
            ->where('custom_fields.in_table','=',true)
            ->get()->toArray();

        return convertToAssoc($array,'name');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     **/
    public function user()
    {
        return $this->belongsTo(\App\Models\User::class, 'customer_id', 'id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     **/
    public function driver()
    {
         
        return $this->belongsTo(\App\Models\User::class, 'driver_id', 'id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     **/
    public function orderStatus()
    {
        return $this->belongsTo(\App\Models\OrderStatus::class,'order_status_id','id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     **/
    public function productOrders()
    {  
        $currentdate=isset($_GET['currentdate']) ? $_GET['currentdate'] : ''; 
        $type=isset($_GET['type']) ? $_GET['type'] : ''; 
        $role=auth()->user(); 
        $role_id=$role->role_id; 
        $user_id=$role->id; 
        $results = DB::table('roles')->where('name','=',$role_id)->get();  
        if(count($results)>0){
            $role_type=$results[0]->role_type; 
        }
        if($role_type=='driver'){
        //if (auth()->user()->hasRole($role_id)) {
        if($currentdate=="today"){
        $date=date("Y-m-d");      
        return $this->hasMany(\App\Models\ProductOrder::class,'order_id','id')
        ->leftJoin('sales_stock', function ($join) {
            $join->on('sales_stock.product_id', '=', 'sales_order_item.product_id');
            $join->on('sales_stock.order_id', '=', 'sales_order_item.order_id');
                 
        })
        ->leftJoin('add_to_bag', function ($join) {
            $join->on('add_to_bag.product_id', '=', 'sales_order_item.product_id');
            $join->on('add_to_bag.order_id', '=', 'sales_order_item.order_id');
                 
        })->leftJoin('catalog_product_entity_varchar', 'sales_order_item.product_id', '=', 'catalog_product_entity_varchar.entity_id')
        ->leftJoin('rejected_order_item', 'rejected_order_item.item_id', '=', 'sales_order_item.item_id')->leftJoin('catalog_product_entity_media_gallery_value_to_entity', 'sales_order_item.product_id', '=', 'catalog_product_entity_media_gallery_value_to_entity.entity_id')->leftJoin('catalog_product_entity_media_gallery', 'catalog_product_entity_media_gallery_value_to_entity.value_id', '=', 'catalog_product_entity_media_gallery.value_id')
         ->leftJoin('catalog_category_product', function ($join) {
            $join->on('sales_order_item.product_id', '=', 'catalog_category_product.product_id');
                 
        })
        ->leftJoin('catalog_category_flat_store_57', function ($join) {
            $join->on('catalog_category_product.category_id', '=', 'catalog_category_flat_store_57.entity_id');
                 
        })->select('sales_order_item.*','catalog_product_entity_media_gallery.value as product_image', 'sales_stock.qty as outofstockqty','add_to_bag.qty as inbagqty','catalog_product_entity_varchar.value as item_barcode','catalog_category_flat_store_57.name as category_name','rejected_order_item.new_qty as updated_qty','rejected_order_item.new_price as updated_price')->where('product_type','=','simple')->where('sales_order_item.driver_id','=',$user_id)->where('sales_order_item.delivery_dates','=',$date)->whereIn('sales_order_item.order_status_id',[1,2,3,4,5,6,8,9,10,11])->where('catalog_product_entity_varchar.attribute_id','=','188')->groupBY('sales_order_item.product_id','sales_order_item.item_id')->orderBy('catalog_category_flat_store_57.name', 'ASC');
        }else{
          return $this->hasMany(\App\Models\ProductOrder::class,'order_id','id')
        ->leftJoin('sales_stock', function ($join) {
            $join->on('sales_stock.product_id', '=', 'sales_order_item.product_id');
            $join->on('sales_stock.order_id', '=', 'sales_order_item.order_id');
                 
        })
        ->leftJoin('add_to_bag', function ($join) {
            $join->on('add_to_bag.product_id', '=', 'sales_order_item.product_id');
            $join->on('add_to_bag.order_id', '=', 'sales_order_item.order_id');
                 
        })->leftJoin('catalog_product_entity_varchar', 'sales_order_item.product_id', '=', 'catalog_product_entity_varchar.entity_id')
        ->leftJoin('rejected_order_item', 'rejected_order_item.item_id', '=', 'sales_order_item.item_id')->leftJoin('catalog_product_entity_media_gallery_value_to_entity', 'sales_order_item.product_id', '=', 'catalog_product_entity_media_gallery_value_to_entity.entity_id')->leftJoin('catalog_product_entity_media_gallery', 'catalog_product_entity_media_gallery_value_to_entity.value_id', '=', 'catalog_product_entity_media_gallery.value_id')
         ->leftJoin('catalog_category_product', function ($join) {
            $join->on('sales_order_item.product_id', '=', 'catalog_category_product.product_id');
                 
        })
        ->leftJoin('catalog_category_flat_store_57', function ($join) {
            $join->on('catalog_category_product.category_id', '=', 'catalog_category_flat_store_57.entity_id');
                 
        })->select('sales_order_item.*','catalog_product_entity_media_gallery.value as product_image', 'sales_stock.qty as outofstockqty','add_to_bag.qty as inbagqty','catalog_product_entity_varchar.value as item_barcode','catalog_category_flat_store_57.name as category_name','rejected_order_item.new_qty as updated_qty','rejected_order_item.new_price as updated_price')->where('product_type','=','simple')->where('sales_order_item.driver_id','=',$user_id)->whereIn('sales_order_item.order_status_id',[1,2,3,4,5,6,8,9,10,11])->where('catalog_product_entity_varchar.attribute_id','=','188')->groupBY('sales_order_item.product_id','sales_order_item.item_id')->orderBy('catalog_category_flat_store_57.name', 'ASC');  
        }
        //}
        }
        else if($role_type=='picker'){
        //if (auth()->user()->hasRole($role_id)) {
        if($currentdate=="today"){
        $date=date("Y-m-d");     
         return $this->hasMany(\App\Models\ProductOrder::class,'order_id','id')
        ->leftJoin('sales_stock', function ($join) {
            $join->on('sales_stock.product_id', '=', 'sales_order_item.product_id');
            $join->on('sales_stock.order_id', '=', 'sales_order_item.order_id');
                 
        })
        ->leftJoin('add_to_bag', function ($join) {
            $join->on('add_to_bag.product_id', '=', 'sales_order_item.product_id');
            $join->on('add_to_bag.order_id', '=', 'sales_order_item.order_id');
                 
        })->leftJoin('catalog_product_entity_varchar', 'sales_order_item.product_id', '=', 'catalog_product_entity_varchar.entity_id')->leftJoin('catalog_product_entity_media_gallery_value_to_entity', 'sales_order_item.product_id', '=', 'catalog_product_entity_media_gallery_value_to_entity.entity_id') ->leftJoin('rejected_order_item', 'rejected_order_item.item_id', '=', 'sales_order_item.item_id')->leftJoin('catalog_product_entity_media_gallery', 'catalog_product_entity_media_gallery_value_to_entity.value_id', '=', 'catalog_product_entity_media_gallery.value_id')
         ->leftJoin('catalog_category_product', function ($join) {
            $join->on('sales_order_item.product_id', '=', 'catalog_category_product.product_id');
                 
        })
        ->leftJoin('catalog_category_flat_store_57', function ($join) {
            $join->on('catalog_category_product.category_id', '=', 'catalog_category_flat_store_57.entity_id');
                 
        })->select('sales_order_item.*','catalog_product_entity_media_gallery.value as product_image', 'sales_stock.qty as outofstockqty','add_to_bag.qty as inbagqty','catalog_product_entity_varchar.value as item_barcode','catalog_category_flat_store_57.name as category_name','rejected_order_item.new_qty as updated_qty','rejected_order_item.new_price as updated_price')->where('product_type','=','simple')->where('sales_order_item.picker_id','=',$user_id)->where('sales_order_item.delivery_dates','=',$date)->whereIn('sales_order_item.order_status_id',[1,2,3,4,5,6,8,9,10,11])->where('catalog_product_entity_varchar.attribute_id','=','188')->groupBY('sales_order_item.product_id','sales_order_item.item_id')->orderBy('catalog_category_flat_store_57.name', 'ASC');   
        }else{
         return $this->hasMany(\App\Models\ProductOrder::class,'order_id','id')
        ->leftJoin('sales_stock', function ($join) {
            $join->on('sales_stock.product_id', '=', 'sales_order_item.product_id');
            $join->on('sales_stock.order_id', '=', 'sales_order_item.order_id');
                 
        })
        ->leftJoin('add_to_bag', function ($join) {
            $join->on('add_to_bag.product_id', '=', 'sales_order_item.product_id');
            $join->on('add_to_bag.order_id', '=', 'sales_order_item.order_id');
                 
        })->leftJoin('catalog_product_entity_varchar', 'sales_order_item.product_id', '=', 'catalog_product_entity_varchar.entity_id')->leftJoin('catalog_product_entity_media_gallery_value_to_entity', 'sales_order_item.product_id', '=', 'catalog_product_entity_media_gallery_value_to_entity.entity_id') ->leftJoin('rejected_order_item', 'rejected_order_item.item_id', '=', 'sales_order_item.item_id')->leftJoin('catalog_product_entity_media_gallery', 'catalog_product_entity_media_gallery_value_to_entity.value_id', '=', 'catalog_product_entity_media_gallery.value_id')
         ->leftJoin('catalog_category_product', function ($join) {
            $join->on('sales_order_item.product_id', '=', 'catalog_category_product.product_id');
        })
        ->leftJoin('catalog_category_flat_store_57', function ($join) {
            $join->on('catalog_category_product.category_id', '=', 'catalog_category_flat_store_57.entity_id');
                 
        })->select('sales_order_item.*','catalog_product_entity_media_gallery.value as product_image', 'sales_stock.qty as outofstockqty','add_to_bag.qty as inbagqty','catalog_product_entity_varchar.value as item_barcode','catalog_category_flat_store_57.name as category_name','rejected_order_item.new_qty as updated_qty','rejected_order_item.new_price as updated_price')->where('product_type','=','simple')->where('sales_order_item.picker_id','=',$user_id)->whereIn('sales_order_item.order_status_id',[1,2,3,4,5,6,8,9,10,11])->where('catalog_product_entity_varchar.attribute_id','=','188')->groupBY('sales_order_item.product_id','sales_order_item.item_id')->orderBy('catalog_category_flat_store_57.name', 'ASC');      
        }
         }else{
          return $this->hasMany(\App\Models\ProductOrder::class,'order_id','entity_id')->leftJoin('sales_stock', 'sales_stock.order_id', '=', 'sales_order_item.order_id')->leftJoin('add_to_bag', 'add_to_bag.order_id', '=', 'sales_order_item.order_id')
             ->leftJoin('catalog_product_entity_varchar', 'sales_order_item.product_id', '=', 'catalog_product_entity_varchar.entity_id')  ->leftJoin('rejected_order_item', 'rejected_order_item.item_id', '=', 'sales_order_item.item_id')->leftJoin('catalog_product_entity_media_gallery_value_to_entity', 'sales_order_item.product_id', '=', 'catalog_product_entity_media_gallery_value_to_entity.entity_id')->leftJoin('catalog_product_entity_media_gallery', 'catalog_product_entity_media_gallery_value_to_entity.value_id', '=', 'catalog_product_entity_media_gallery.value_id')->select('sales_order_item.*','catalog_product_entity_media_gallery.value as product_image', 'sales_stock.qty as outofstockqty','add_to_bag.qty as inbagqty','catalog_product_entity_varchar.value as item_barcode','rejected_order_item.new_qty as updated_qty','rejected_order_item.new_price as updated_price')->where('product_type','=','simple')->where('catalog_product_entity_varchar.attribute_id','=','188');
         }
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsToMany
     **/
    public function products()
    {
       
        return $this->belongsToMany(\App\Models\Product::class, 'sales_order_item');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     **/
    public function payment()
    {
        return $this->belongsTo(\App\Models\Payment::class,'id','parent_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     **/
    public function deliveryAddress()
    {
        return $this->belongsTo(\App\Models\DeliveryAddress::class, 'delivery_address_id', 'entity_id');
    }
    
}
