<?php

namespace App\Models;

use Eloquent as Model;

/**
 * Class Order
 * @package App\Models
 * @version August 31, 2019, 11:11 am UTC
 *
 * @property \App\Models\User user
 * @property \App\Models\DeliveryAddress deliveryAddress
 * @property \App\Models\Payment payment
 * @property \App\Models\OrderStatus orderStatus
 * @property \App\Models\ProductOrder[] productOrders
 * @property integer user_id
 * @property integer order_status_id
 * @property integer payment_id
 * @property double tax
 * @property double delivery_fee
 * @property string id
 * @property int delivery_address_id
 * @property string hint
 * @property integer picker_id
 */
class Orderitem extends Model
{

    protected $primaryKey = 'item_id';
    public $table = 'sales_order_item';
    
    public $fillable = [
        'item_id',
      
        'customer_id',
       
        'driver_id',
        'order_status_id',
        'picker_id',
    ];

    /**
     * The attributes that should be casted to native types.
     *
     * @var array
     */
    protected $casts = [
        'item_id' => 'integer',
        
        'customer_id' => 'integer',
       
        'driver_id' => 'integer',
        'order_status_id' => 'integer',
        'picker_id'=> 'integer',
    ];

    /**
     * Validation rules
     *
     * @var array
     */
    public static $rules = [
        // 'user_id' => 'required|exists:users,id',
        // 'order_status_id' => 'required|exists:order_statuses,id',
        // 'payment_id' => 'exists:payments,id',
        // 'driver_id' => 'nullable|exists:users,id',
    ];

    /**
     * New Attributes
     *
     * @var array
     */
    protected $appends = [
        'custom_fields',
        
    ];

    public function customFieldsValues()
    {
        return $this->morphMany('App\Models\CustomFieldValue', 'customizable');
    }

    public function getCustomFieldsAttribute()
    {
        $hasCustomField = in_array(static::class,setting('custom_field_models',[]));
        if (!$hasCustomField){
            return [];
        }
        $array = $this->customFieldsValues()
            ->join('custom_fields','custom_fields.id','=','custom_field_values.custom_field_id')
            ->where('custom_fields.in_table','=',true)
            ->get()->toArray();

        return convertToAssoc($array,'name');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     **/
    public function user()
    {
        return $this->belongsTo(\App\Models\User::class, 'customer_id', 'id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     **/
    public function driver()
    {
        return $this->belongsTo(\App\Models\User::class, 'driver_id', 'id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     **/
    public function orderStatus()
    {
        return $this->belongsTo(\App\Models\OrderStatus::class,'order_status_id','id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     **/
    public function productOrders()
    {
        $type=isset($_GET['type']) ? $_GET['type'] : ''; 
        $role=auth()->user(); 
        $role_id=$role->role_id; 
        $user_id=$role->id; 
        $results = DB::table('roles')->where('name','=',$role_id)->get();  
        if(count($results)>0){
            $role_type=$results[0]->role_type; 
        }
        if($role_type=='driver'){
         //if (auth()->user()->hasRole($role_id)) {
        return $this->hasMany(\App\Models\ProductOrder::class,'order_id','id')->leftJoin('sales_stock', 'sales_stock.product_id', '=', 'sales_order_item.product_id')->select('sales_order_item.*', 'sales_stock.qty')->where('product_type','=','simple')->where('driver_id','=',$user_id)->where('sub_status','!=','canceled');
         //}
        }
        if($role_type=='picker'){
         //if (auth()->user()->hasRole($role_id)) {
        return $this->hasMany(\App\Models\ProductOrder::class,'order_id','id')->leftJoin('sales_stock', 'sales_stock.product_id', '=', 'sales_order_item.product_id')->select('sales_order_item.*', 'sales_stock.qty')->where('product_type','=','simple')->where('picker_id','=',$user_id)->where('sub_status','!=','canceled');
         //}
        }
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsToMany
     **/
    public function products()
    {
        return $this->belongsToMany(\App\Models\Product::class, 'sales_order_item');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     **/
    public function payment()
    {
        return $this->belongsTo(\App\Models\Payment::class,'id','item_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     **/
    public function deliveryAddress()
    {
        return $this->belongsTo(\App\Models\DeliveryAddress::class, 'delivery_address_id', 'item_id');
    }
    
}
