<?php
/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('login/{service}', 'Auth\LoginController@redirectToProvider');
Route::get('login/{service}/callback', 'Auth\LoginController@handleProviderCallback');
Auth::routes();
Route::get('register', function(){
    return redirect('login');
});
Route::get('payments/failed', 'PayPalController@index')->name('payments.failed');
Route::get('payments/razorpay/checkout', 'RazorPayController@checkout');
Route::post('payments/razorpay/pay-success/{userId}/{deliveryAddressId?}/{couponCode?}', 'RazorPayController@paySuccess');
Route::get('payments/razorpay', 'RazorPayController@index');

Route::get('payments/paypal/express-checkout', 'PayPalController@getExpressCheckout')->name('paypal.express-checkout');
Route::get('payments/paypal/express-checkout-success', 'PayPalController@getExpressCheckoutSuccess');
Route::get('payments/paypal', 'PayPalController@index')->name('paypal.index');

Route::get('firebase/sw-js','AppSettingController@initFirebase');


Route::get('storage/app/public/{id}/{conversion}/{filename?}', 'UploadController@storage');
Route::middleware('auth')->group(function () {
    Route::get('logs', '\Rap2hpoutre\LaravelLogViewer\LogViewerController@index');
    Route::get('/', 'DashboardController@index')->name('dashboard');

    Route::post('uploads/store', 'UploadController@store')->name('medias.create');
    Route::get('users/profile', 'UserController@profile')->name('users.profile');
    Route::post('users/remove-media', 'UserController@removeMedia');
    Route::resource('users', 'UserController');
    Route::get('dashboard', 'DashboardController@index')->name('dashboard');

    Route::group(['middleware' => ['permission:medias']], function () {
        Route::get('uploads/all/{collection?}', 'UploadController@all');
        Route::get('uploads/collectionsNames', 'UploadController@collectionsNames');
        Route::post('uploads/clear', 'UploadController@clear')->name('medias.delete');
        Route::get('medias', 'UploadController@index')->name('medias');
        Route::get('uploads/clear-all', 'UploadController@clearAll');
    });

    Route::group(['middleware' => ['permission:permissions.index']], function () {
        Route::get('permissions/role-has-permission', 'PermissionController@roleHasPermission');
        Route::get('permissions/refresh-permissions', 'PermissionController@refreshPermissions');
    });
    Route::group(['middleware' => ['permission:permissions.index']], function () {
        Route::post('permissions/give-permission-to-role', 'PermissionController@givePermissionToRole');
        Route::post('permissions/revoke-permission-to-role', 'PermissionController@revokePermissionToRole');
    });

    Route::group(['middleware' => ['permission:app-settings']], function () {
        Route::prefix('settings')->group(function () {
            Route::resource('permissions', 'PermissionController');
            Route::resource('roles', 'RoleController');
            Route::resource('customFields', 'CustomFieldController');
            Route::resource('currencies', 'CurrencyController')->except([
                'show'
            ]);
            Route::get('users/login-as-user/{id}', 'UserController@loginAsUser')->name('users.login-as-user');
            Route::patch('update', 'AppSettingController@update');
            Route::patch('translate', 'AppSettingController@translate');
            Route::get('sync-translation', 'AppSettingController@syncTranslation');
            Route::get('clear-cache', 'AppSettingController@clearCache');
            Route::get('check-update', 'AppSettingController@checkForUpdates');
            // disable special character and number in route params
            Route::get('/{type?}/{tab?}', 'AppSettingController@index')
                ->where('type', '[A-Za-z]*')->where('tab', '[A-Za-z]*')->name('app-settings');
        });
    });

    Route::post('fields/remove-media','FieldController@removeMedia');
    Route::resource('fields', 'FieldController')->except([
        'show'
    ]);

    Route::post('markets/remove-media', 'MarketController@removeMedia');
    Route::get('requestedMarkets', 'MarketController@requestedMarkets')->name('requestedMarkets.index'); //adeed
    Route::resource('markets', 'MarketController')->except([
        'show'
    ]);

    Route::post('categories/remove-media', 'CategoryController@removeMedia'); 
    Route::resource('categories', 'CategoryController')->except([
        'show'
    ]);

    Route::resource('faqCategories', 'FaqCategoryController')->except([
        'show'
    ]);

    Route::resource('orderStatuses', 'OrderStatusController')->except([
        'create', 'store', 'destroy'
    ]);;

    Route::post('products/remove-media', 'ProductController@removeMedia');
    Route::resource('products', 'ProductController')->except([
        'show'
    ]);

    Route::post('galleries/remove-media', 'GalleryController@removeMedia');
    Route::resource('galleries', 'GalleryController')->except([
        'show'
    ]);

    Route::resource('productReviews', 'ProductReviewController')->except([
        'show'
    ]);

    Route::post('options/remove-media', 'OptionController@removeMedia');
    

    Route::resource('payments', 'PaymentController')->except([
        'create', 'store','edit', 'destroy'
    ]);;

    Route::resource('faqs', 'FaqController')->except([
        'show'
    ]);
    Route::resource('marketReviews', 'MarketReviewController')->except([
        'show'
    ]);

    Route::resource('favorites', 'FavoriteController')->except([
        'show'
    ]);
    
    Route::get('orders/oldindexcode',['as'=>'orders.oldindexcode','uses'=>'OrderController@oldIndexCode']); 
    Route::resource('orders', 'OrderController');
    Route::get('orders/orderedit/{id}',['as'=>'orders.orderedit','uses'=>'OrderController@orderedit']);
     Route::get('orders/reload/{id}',['as'=>'orders.reload','uses'=>'OrderController@reload']);
    Route::get('orders/orderdestroy/{id}',['as'=>'orders.orderdestroy','uses'=>'OrderController@orderdestroy']);
    Route::patch('orders/orderupdate/{id}',['as'=>'orders.orderupdate','uses'=>'OrderController@orderupdate']);
    Route::post('/update_quantity',['as'=>'orders.updateQuantity','uses'=>'OrderController@orderUpdateQuantity']);
       Route::post('/deleteitem',['as'=>'orders.deleteitem','uses'=>'OrderController@deleteitem']);
    Route::get('orders/delivery/{id}',['as'=>'orders.delivery','uses'=>'OrderController@orderdelivery']);
    Route::get('orders/pickinglist/{id}',['as'=>'orders.pickinglist','uses'=>'OrderController@orderpickinglist']); 
    Route::get('orders/tax/{id}',['as'=>'orders.tax','uses'=>'OrderController@ordertax']); 
    Route::get('/notifications_read',['as'=>'notification.notifications_read','uses'=>'NotificationController@notificationsRead']);
    Route::resource('notifications', 'NotificationController')->except([
        'create', 'store', 'update','edit',
    ]);

    Route::resource('carts', 'CartController')->except([
        'show','store','create'
    ]);
    Route::resource('deliveryAddresses', 'DeliveryAddressController')->except([
        'show'
    ]);

    Route::resource('drivers', 'DriverController')->except([
        'show'
    ]);

    Route::resource('earnings', 'EarningController')->except([
        'show','edit','update'
    ]);

    Route::resource('driversPayouts', 'DriversPayoutController')->except([
        'show','edit','update'
    ]);

    Route::resource('marketsPayouts', 'MarketsPayoutController')->except([
        'show','edit','update'
    ]);

    Route::resource('optionGroups', 'OptionGroupController')->except([
        'show'
    ]);

    Route::post('options/remove-media','OptionController@removeMedia');

    Route::resource('options', 'OptionController')->except([
        'show'
    ]);
    Route::resource('coupons', 'CouponController')->except([
        'show'
    ]);
    Route::post('slides/remove-media','SlideController@removeMedia');
    Route::resource('slides', 'SlideController')->except([
        'show'
    ]);
    
Route::resource('vehicle','VehicleController');
Route::get('vehicle',['as'=>'vehicle.index','uses'=>'VehicleController@index']);
Route::post('vehicle/create',['as'=>'vehicle.store','uses'=>'VehicleController@store']);
Route::get('vehicle/edit/{id}',['as'=>'vehicle.edit','uses'=>'VehicleController@edit']);
Route::patch('vehicle/{id}',['as'=>'vehicle.update','uses'=>'VehicleController@update']);
Route::get('vehicle/destroy/{id}',['as'=>'vehicle.destroy','uses'=>'VehicleController@destroy']);
Route::get('vehicle/{id}',['as'=>'vehicle.show','uses'=>'VehicleController@show']);

Route::resource('store','StoreController');
Route::get('store',['as'=>'store.index','uses'=>'StoreController@index']);


Route::resource('delivery_slot','DeliveryslotController');
Route::get('delivery_slot',['as'=>'delivery_slot.index','uses'=>'DeliveryslotController@index']);
Route::post('delivery_slot/create',['as'=>'delivery_slot.store','uses'=>'DeliveryslotController@store']);
Route::get('delivery_slot/edit/{id}',['as'=>'delivery_slot.edit','uses'=>'DeliveryslotController@edit']);
Route::patch('delivery_slot/{id}',['as'=>'delivery_slot.update','uses'=>'DeliveryslotController@update']);
Route::get('delivery_slot/destroy/{id}',['as'=>'delivery_slot.destroy','uses'=>'DeliveryslotController@destroy']);
Route::get('delivery_slot/{id}',['as'=>'delivery_slot.show','uses'=>'DeliveryslotController@show']); 


Route::resource('driver_assign','DriverassignController');
Route::get('driver_assign',['as'=>'driver_assign.index','uses'=>'DriverassignController@index']);
Route::post('driver_assign/create',['as'=>'driver_assign.store','uses'=>'DriverassignController@store']);
Route::get('driver_assign/edit/{id}',['as'=>'driver_assign.edit','uses'=>'DriverassignController@edit']);
Route::patch('driver_assign/{id}',['as'=>'driver_assign.update','uses'=>'DriverassignController@update']);
Route::get('driver_assign/destroy/{id}',['as'=>'driver_assign.destroy','uses'=>'DriverassignController@destroy']);
Route::get('driver_assign/{id}',['as'=>'driver_assign.show','uses'=>'DriverassignController@show']);

Route::resource('locations','LocationsController');
Route::get('locations',['as'=>'locations.index','uses'=>'LocationsController@index']);
Route::post('locations/create',['as'=>'locations.store','uses'=>'LocationsController@store']);
Route::get('locations/edit/{id}',['as'=>'locations.edit','uses'=>'LocationsController@edit']);
Route::patch('locations/{id}',['as'=>'locations.update','uses'=>'LocationsController@update']);
Route::get('locations/destroy/{id}',['as'=>'locations.destroy','uses'=>'LocationsController@destroy']);
Route::get('locations/{id}',['as'=>'locations.show','uses'=>'LocationsController@show']);

Route::resource('location_details','LocationdetailsController');
Route::get('location_details',['as'=>'location_details.index','uses'=>'LocationdetailsController@index']);
Route::post('location_details/create',['as'=>'location_details.store','uses'=>'LocationdetailsController@store']);
Route::get('location_details/edit/{id}',['as'=>'location_details.edit','uses'=>'LocationdetailsController@edit']);
Route::patch('location_details/{id}',['as'=>'location_details.update','uses'=>'LocationdetailsController@update']);
Route::get('location_details/destroy/{id}',['as'=>'location_details.destroy','uses'=>'LocationdetailsController@destroy']);
Route::get('location_details/{id}',['as'=>'location_details.show','uses'=>'LocationdetailsController@show']);

Route::resource('contact_details','ContactDetailsController');
Route::get('contact_details',['as'=>'contact_details.index','uses'=>'ContactDetailsController@index']);
Route::post('contact_details/create',['as'=>'contact_details.store','uses'=>'ContactDetailsController@store']);
Route::get('contact_details/destroy/{id}',['as'=>'contact_details.destroy','uses'=>'ContactDetailsController@destroy']);
Route::get('contact_details/edit/{id}',['as'=>'contact_details.edit','uses'=>'ContactDetailsController@edit']);
Route::patch('contact_details/{id}',['as'=>'contact_details.update','uses'=>'ContactDetailsController@update']);
Route::get('contact_details/{id}',['as'=>'contact_details.show','uses'=>'ContactDetailsController@show']);

Route::resource('labels','LabelsController');
Route::get('labels',['as'=>'labels.index','uses'=>'LabelsController@index']);
Route::post('labels/create',['as'=>'labels.store','uses'=>'LabelsController@store']);
Route::get('labels/edit/{id}',['as'=>'labels.edit','uses'=>'LabelsController@edit']);
Route::patch('labels/{id}',['as'=>'labels.update','uses'=>'LabelsController@update']);
Route::get('labels/destroy/{id}',['as'=>'labels.destroy','uses'=>'LabelsController@destroy']);
Route::get('labels/{id}',['as'=>'labels.show','uses'=>'LabelsController@show']);


Route::resource('label_description','LabeldescController');
Route::get('label_description',['as'=>'label_description.index','uses'=>'LabeldescController@index']);
Route::post('label_description/create',['as'=>'label_description.store','uses'=>'LabeldescController@store']);
Route::get('label_description/edit/{id}',['as'=>'label_description.edit','uses'=>'LabeldescController@edit']);
Route::patch('label_description/{id}',['as'=>'label_description.update','uses'=>'LabeldescController@update']);
Route::get('label_description/destroy/{id}',['as'=>'label_description.destroy','uses'=>'LabeldescController@destroy']);
Route::get('label_description/{id}',['as'=>'label_description.show','uses'=>'LabeldescController@show']);

Route::resource('erp','ErpController');
Route::get('erp',['as'=>'erp.index','uses'=>'ErpController@index']);
Route::post('erp/create',['as'=>'erp.store','uses'=>'ErpController@store']);
Route::get('erp/edit/{id}',['as'=>'erp.edit','uses'=>'ErpController@edit']);
Route::patch('erp/{id}',['as'=>'erp.update','uses'=>'ErpController@update']);
Route::get('erp/destroy/{id}',['as'=>'erp.destroy','uses'=>'ErpController@destroy']);
Route::get('erp/{id}',['as'=>'erp.show','uses'=>'ErpController@show']);

Route::resource('erp_store','ErpStoreController');
Route::get('erp_store',['as'=>'erp_store.index','uses'=>'ErpStoreController@index']);
Route::post('erp_store/create',['as'=>'erp_store.store','uses'=>'ErpStoreController@store']);
Route::get('erp_store/edit/{id}',['as'=>'erp_store.edit','uses'=>'ErpStoreController@edit']);
Route::patch('erp_store/{id}',['as'=>'erp_store.update','uses'=>'ErpStoreController@update']);
Route::get('erp_store/destroy/{id}',['as'=>'erp_store.destroy','uses'=>'ErpStoreController@destroy']);
Route::get('erp_store/{id}',['as'=>'erp_store.show','uses'=>'ErpStoreController@show']);

Route::resource('exportexcel','ExportExcelController');
Route::get('exportexcel',['as'=>'exportexcel.index','uses'=>'ExportExcelController@index']);
Route::get('exportexcel/excel',['as'=>'exportexcel.show','uses'=>'ExportExcelController@show']);
Route::get('exportexcel/text/excel',['as'=>'exportexcel.textExcel','uses'=>'ExportExcelController@textExcel']);

Route::resource('sms','SmsController');
Route::get('sms',['as'=>'sms.index','uses'=>'SmsController@index']);
Route::post('sms/create',['as'=>'sms.store','uses'=>'SmsController@store']);
Route::get('sms/edit/{id}',['as'=>'sms.edit','uses'=>'SmsController@edit']);
Route::patch('sms/{id}',['as'=>'sms.update','uses'=>'SmsController@update']);
Route::get('sms/destroy/{id}',['as'=>'sms.destroy','uses'=>'SmsController@destroy']);
Route::get('sms/{id}',['as'=>'sms.show','uses'=>'SmsController@show']);

Route::resource('trn_no','TrnController');
Route::get('trn_no',['as'=>'trn_no.index','uses'=>'TrnController@index']);
Route::post('trn_no/create',['as'=>'trn_no.store','uses'=>'TrnController@store']);
Route::get('trn_no/edit/{id}',['as'=>'trn_no.edit','uses'=>'TrnController@edit']);
Route::patch('trn_no/{id}',['as'=>'trn_no.update','uses'=>'TrnController@update']);
Route::get('trn_no/destroy/{id}',['as'=>'trn_no.destroy','uses'=>'TrnController@destroy']);
Route::get('trn_no/{id}',['as'=>'trn_no.show','uses'=>'TrnController@show']);


Route::resource('cashier_name','CashierNameController');
Route::get('cashier_name',['as'=>'cashier_name.index','uses'=>'CashierNameController@index']);
Route::post('cashier_name/create',['as'=>'cashier_name.store','uses'=>'CashierNameController@store']);
Route::get('cashier_name/edit/{id}',['as'=>'cashier_name.edit','uses'=>'CashierNameController@edit']);
Route::patch('cashier_name/{id}',['as'=>'cashier_name.update','uses'=>'CashierNameController@update']);
Route::get('cashier_name/destroy/{id}',['as'=>'cashier_name.destroy','uses'=>'CashierNameController@destroy']);
Route::get('cashier_name/{id}',['as'=>'cashier_name.show','uses'=>'CashierNameController@show']);

Route::resource('payment_time_duration','PaymentTimeDurationController');
Route::get('payment_time_duration',['as'=>'payment_time_duration.index','uses'=>'PaymentTimeDurationController@index']);
Route::post('payment_time_duration/create',['as'=>'payment_time_duration.store','uses'=>'PaymentTimeDurationController@store']);
Route::get('payment_time_duration/edit/{id}',['as'=>'payment_time_duration.edit','uses'=>'PaymentTimeDurationController@edit']);
Route::patch('payment_time_duration/{id}',['as'=>'payment_time_duration.update','uses'=>'PaymentTimeDurationController@update']);
Route::get('payment_time_duration/destroy/{id}',['as'=>'payment_time_duration.destroy','uses'=>'PaymentTimeDurationController@destroy']);
Route::get('payment_time_duration/{id}',['as'=>'payment_time_duration.show','uses'=>'PaymentTimeDurationController@show']);

Route::resource('reinitiate_time_duration','ReinitiateTimeDurationController');
Route::get('reinitiate_time_duration',['as'=>'reinitiate_time_duration.index','uses'=>'ReinitiateTimeDurationController@index']);
Route::post('reinitiate_time_duration/create',['as'=>'reinitiate_time_duration.store','uses'=>'ReinitiateTimeDurationController@store']);
Route::get('reinitiate_time_duration/edit/{id}',['as'=>'reinitiate_time_duration.edit','uses'=>'ReinitiateTimeDurationController@edit']);
Route::patch('reinitiate_time_duration/{id}',['as'=>'reinitiate_time_duration.update','uses'=>'ReinitiateTimeDurationController@update']);
Route::get('reinitiate_time_duration/destroy/{id}',['as'=>'reinitiate_time_duration.destroy','uses'=>'ReinitiateTimeDurationController@destroy']);
Route::get('reinitiate_time_duration/{id}',['as'=>'reinitiate_time_duration.show','uses'=>'ReinitiateTimeDurationController@show']);


Route::resource('notification_order_sound','NotificationOrderSoundController');
Route::get('notification_order_sound',['as'=>'notification_order_sound.index','uses'=>'NotificationOrderSoundController@index']);
Route::post('notification_order_sound/create',['as'=>'reinitiate_time_duration.store','uses'=>'NotificationOrderSoundController@store']);
Route::get('notification_order_sound/edit/{id}',['as'=>'reinitiate_time_duration.edit','uses'=>'NotificationOrderSoundController@edit']);
Route::patch('notification_order_sound/{id}',['as'=>'reinitiate_time_duration.update','uses'=>'NotificationOrderSoundController@update']);
Route::get('notification_order_sound/destroy/{id}',['as'=>'notification_order_sound.destroy','uses'=>'NotificationOrderSoundController@destroy']);
Route::get('notification_order_sound/{id}',['as'=>'reinitiate_time_duration.show','uses'=>'NotificationOrderSoundController@show']);

Route::resource('mobile_app_version','MobileAppVersionController');
Route::get('mobile_app_version',['as'=>'mobile_app_version.index','uses'=>'MobileAppVersionController@index']);
Route::post('mobile_app_version/create',['as'=>'mobile_app_version.store','uses'=>'MobileAppVersionController@store']);
Route::get('mobile_app_version/edit/{id}',['as'=>'mobile_app_version.edit','uses'=>'MobileAppVersionController@edit']);
Route::patch('mobile_app_version/{id}',['as'=>'mobile_app_version.update','uses'=>'MobileAppVersionController@update']);
Route::get('mobile_app_version/destroy/{id}',['as'=>'mobile_app_version.destroy','uses'=>'MobileAppVersionController@destroy']);
Route::get('mobile_app_version/{id}',['as'=>'mobile_app_version.show','uses'=>'MobileAppVersionController@show']);

Route::resource('service_maintenance','ServiceMaintenanceController');
Route::get('service_maintenance',['as'=>'service_maintenance.index','uses'=>'ServiceMaintenanceController@index']);
Route::post('service_maintenance/create',['as'=>'service_maintenance.store','uses'=>'ServiceMaintenanceController@store']);
Route::get('service_maintenance/edit/{id}',['as'=>'service_maintenance.edit','uses'=>'ServiceMaintenanceController@edit']);
Route::patch('service_maintenance/{id}',['as'=>'service_maintenance.update','uses'=>'ServiceMaintenanceController@update']);
Route::get('service_maintenance/destroy/{id}',['as'=>'mobile_app_version.destroy','uses'=>'ServiceMaintenanceController@destroy']);
Route::get('service_maintenance/{id}',['as'=>'service_maintenance.show','uses'=>'ServiceMaintenanceController@show']);

Route::resource('reports_delivery_date','ReportDeliveryDateController');
Route::get('reports_delivery_date',['as'=>'reports_delivery_date.index','uses'=>'ReportDeliveryDateController@index']);
Route::post('reports_delivery_date/create',['as'=>'reports_delivery_date.store','uses'=>'ReportDeliveryDateController@store']);
Route::get('reports_delivery_date/edit/{id}',['as'=>'reports_delivery_date.edit','uses'=>'ReportDeliveryDateController@edit']);
Route::patch('reports_delivery_date/{id}',['as'=>'reports_delivery_date.update','uses'=>'ReportDeliveryDateController@update']);
Route::get('reports_delivery_date/destroy/{id}',['as'=>'reports_delivery_date.destroy','uses'=>'ReportDeliveryDateController@destroy']);
Route::get('reports_delivery_date/{id}',['as'=>'reports_delivery_date.show','uses'=>'ReportDeliveryDateController@show']);

Route::resource('reports_payment','ReportPaymentController');
Route::get('reports_payment',['as'=>'reports_payment.index','uses'=>'ReportPaymentController@index']);
Route::post('reports_payment/create',['as'=>'reports_payment.store','uses'=>'ReportPaymentController@store']);
Route::get('reports_payment/edit/{id}',['as'=>'reports_payment.edit','uses'=>'ReportPaymentController@edit']);
Route::patch('reports_payment/{id}',['as'=>'reports_payment.update','uses'=>'ReportPaymentController@update']);
Route::get('reports_payment/destroy/{id}',['as'=>'reports_payment.destroy','uses'=>'ReportPaymentController@destroy']);
Route::get('reports_payment/{id}',['as'=>'reports_payment.show','uses'=>'ReportPaymentController@show']);

Route::resource('reports_picking_summary','ReportPickingSummaryController');
Route::get('reports_picking_summary',['as'=>'reports_picking_summary.index','uses'=>'ReportPickingSummaryController@index']);
Route::post('reports_picking_summary/create',['as'=>'reports_picking_summary.store','uses'=>'ReportPickingSummaryController@store']);
Route::get('reports_picking_summary/edit/{id}',['as'=>'reports_picking_summary.edit','uses'=>'ReportPickingSummaryController@edit']);
Route::patch('reports_picking_summary/{id}',['as'=>'reports_picking_summary.update','uses'=>'ReportPickingSummaryController@update']);
Route::get('reports_picking_summary/destroy/{id}',['as'=>'reports_picking_summary.destroy','uses'=>'ReportPickingSummaryController@destroy']);
Route::get('reports_picking_summary/{id}',['as'=>'reports_picking_summary.show','uses'=>'ReportPickingSummaryController@show']);

Route::resource('reports_new_account','ReportNewAccountController');
Route::get('reports_new_account',['as'=>'reports_new_account.index','uses'=>'ReportNewAccountController@index']);
Route::post('reports_new_account/create',['as'=>'reports_new_account.store','uses'=>'ReportNewAccountController@store']);
Route::get('reports_new_account/edit/{id}',['as'=>'reports_new_account.edit','uses'=>'ReportNewAccountController@edit']);
Route::patch('reports_new_account/{id}',['as'=>'reports_new_account.update','uses'=>'ReportNewAccountController@update']);
Route::get('reports_new_account/destroy/{id}',['as'=>'reports_new_account.destroy','uses'=>'ReportNewAccountController@destroy']);
Route::get('reports_new_account/{id}',['as'=>'reports_new_account.show','uses'=>'ReportNewAccountController@show']);

Route::resource('reports_delivery_summary','ReportDeliverySummaryController');
Route::get('reports_delivery_summary',['as'=>'reports_delivery_summary.index','uses'=>'ReportDeliverySummaryController@index']);
Route::post('reports_delivery_summary/create',['as'=>'reports_delivery_summary.store','uses'=>'ReportDeliverySummaryController@store']);
Route::get('reports_delivery_summary/edit/{id}',['as'=>'reports_delivery_summary.edit','uses'=>'ReportDeliverySummaryController@edit']);
Route::patch('reports_delivery_summary/{id}',['as'=>'reports_delivery_summary.update','uses'=>'ReportDeliverySummaryController@update']);
Route::get('reports_delivery_summary/destroy/{id}',['as'=>'reports_delivery_summary.destroy','uses'=>'ReportDeliverySummaryController@destroy']);
Route::get('reports_delivery_summary/{id}',['as'=>'reports_delivery_summary.show','uses'=>'ReportDeliverySummaryController@show']);

Route::resource('reports_picking_detail','ReportPickingDetailController');
Route::get('reports_picking_detail',['as'=>'reports_picking_detail.index','uses'=>'ReportPickingDetailController@index']);
Route::post('reports_picking_detail/create',['as'=>'reports_picking_detail.store','uses'=>'ReportPickingDetailController@store']);
Route::get('reports_picking_detail/edit/{id}',['as'=>'reports_picking_detail.edit','uses'=>'ReportPickingDetailController@edit']);
Route::patch('reports_picking_detail/{id}',['as'=>'reports_picking_detail.update','uses'=>'ReportPickingDetailController@update']);
Route::get('reports_picking_detail/destroy/{id}',['as'=>'reports_picking_detail.destroy','uses'=>'ReportPickingDetailController@destroy']);
Route::get('reports_picking_detail/{id}',['as'=>'reports_picking_detail.show','uses'=>'ReportPickingDetailController@show']);

Route::resource('reports_delivery_detail','ReportDeliveryDetailController');
Route::get('reports_delivery_detail',['as'=>'reports_delivery_detail.index','uses'=>'ReportDeliveryDetailController@index']);
Route::post('reports_delivery_detail/create',['as'=>'reports_delivery_detail.store','uses'=>'ReportDeliveryDetailController@store']);
Route::get('reports_delivery_detail/edit/{id}',['as'=>'reports_delivery_detail.edit','uses'=>'ReportDeliveryDetailController@edit']);
Route::patch('reports_delivery_detail/{id}',['as'=>'reports_delivery_detail.update','uses'=>'ReportDeliveryDetailController@update']);
Route::get('reports_delivery_detail/destroy/{id}',['as'=>'reports_delivery_detail.destroy','uses'=>'ReportDeliveryDetailController@destroy']);
Route::get('reports_delivery_detail/{id}',['as'=>'reports_delivery_detail.show','uses'=>'ReportDeliveryDetailController@show']);

Route::resource('reports_coupon_redeem','ReportCouponRedeemController');
Route::get('reports_coupon_redeem',['as'=>'reports_coupon_redeem.index','uses'=>'ReportCouponRedeemController@index']);
Route::post('reports_coupon_redeem/create',['as'=>'reports_coupon_redeem.store','uses'=>'ReportCouponRedeemController@store']);
Route::get('reports_coupon_redeem/edit/{id}',['as'=>'reports_coupon_redeem.edit','uses'=>'ReportCouponRedeemController@edit']);
Route::patch('reports_coupon_redeem/{id}',['as'=>'reports_coupon_redeem.update','uses'=>'ReportCouponRedeemController@update']);
Route::get('reports_coupon_redeem/destroy/{id}',['as'=>'reports_coupon_redeem.destroy','uses'=>'ReportCouponRedeemController@destroy']);
Route::get('reports_coupon_redeem/{id}',['as'=>'reports_coupon_redeem.show','uses'=>'ReportCouponRedeemController@show']);

Route::resource('category','CategoriesController');
Route::get('category',['as'=>'category.index','uses'=>'CategoriesController@index']);
Route::post('category/create',['as'=>'category.store','uses'=>'CategoriesController@store']);
Route::get('category/edit/{id}',['as'=>'category.edit','uses'=>'CategoriesController@edit']);
Route::patch('category/{id}',['as'=>'category.update','uses'=>'CategoriesController@update']);
Route::get('category/destroy/{id}',['as'=>'category.destroy','uses'=>'CategoriesController@destroy']);
Route::get('category/{id}',['as'=>'category.show','uses'=>'CategoriesController@show']);
//pickup fn
Route::resource('pickup','PickupController');
Route::get('pickup',['as'=>'pickup.index','uses'=>'PickupController@index']);
Route::post('pickup/create',['as'=>'pickup.store','uses'=>'PickupController@store']);
Route::get('pickup/edit/{id}',['as'=>'pickup.edit','uses'=>'PickupController@edit']);
Route::patch('pickup/{id}',['as'=>'pickup.update','uses'=>'PickupController@update']);
Route::get('pickup/destroy/{id}',['as'=>'pickup.destroy','uses'=>'PickupController@destroy']);
Route::get('pickup/{id}',['as'=>'pickup.show','uses'=>'PickupController@show']);

Route::resource('productsavailable','ProductAvailableController');
Route::get('productsavailable',['as'=>'productsavailable.index','uses'=>'ProductAvailableController@index']);
Route::post('productsavailable/create',['as'=>'productsavailable.store','uses'=>'ProductAvailableController@store']);
Route::get('productsavailable/edit/{id}',['as'=>'productsavailable.edit','uses'=>'ProductAvailableController@edit']);
Route::patch('productsavailable/{id}',['as'=>'productsavailable.update','uses'=>'ProductAvailableController@update']);
Route::get('productsavailable/destroy/{id}',['as'=>'productsavailable.destroy','uses'=>'ProductAvailableController@destroy']);
Route::get('productsavailable/{id}',['as'=>'productsavailable.show','uses'=>'ProductAvailableController@show']);

Route::resource('return','ReturnController');
Route::get('return',['as'=>'return.index','uses'=>'ReturnController@index']);
Route::post('return/create',['as'=>'return.store','uses'=>'ReturnController@store']);
Route::get('return/edit/{id}',['as'=>'return.edit','uses'=>'ReturnController@edit']);
Route::patch('return/{id}',['as'=>'return.update','uses'=>'ReturnController@update']);
Route::patch('returnupdate/{id}',['as'=>'return.returnupdate','uses'=>'ReturnController@returnupdate']);
Route::get('return/destroy/{id}',['as'=>'return.destroy','uses'=>'ReturnController@destroy']);
Route::get('return/{id}',['as'=>'return.show','uses'=>'ReturnController@show']);
Route::get('return/create/creditmemo',['as'=>'return.creditmemo','uses'=>'ReturnController@creditmemo']);
Route::post('return/refund/refundcreditmemo',['as'=>'return.refund','uses'=>'ReturnController@refundcreditmemo']);

Route::resource('customers','CustomersController');
Route::get('customers',['as'=>'customers.index','uses'=>'CustomersController@index']);
Route::post('customers/create',['as'=>'customers.store','uses'=>'CustomersController@store']);
Route::get('customers/edit/{id}',['as'=>'customers.edit','uses'=>'CustomersController@edit']);
Route::patch('customers/{id}',['as'=>'customers.update','uses'=>'CustomersController@update']);
Route::get('customers/destroy/{id}',['as'=>'customers.destroy','uses'=>'CustomersController@destroy']);
Route::get('customers/{id}',['as'=>'customers.show','uses'=>'CustomersController@show']);
Route::get('customers/addressedit/view',['as'=>'customers.addressedit','uses'=>'CustomersController@addressedit']);
Route::get('customers/addressupdate/view',['as'=>'customers.addressupdate','uses'=>'CustomersController@addressupdate']);

Route::resource('vehiclemanage','VehiclemanageController');
Route::get('vehiclemanage',['as'=>'vehiclemanage.index','uses'=>'VehiclemanageController@index']);
Route::post('vehiclemanage/store',['as'=>'vehiclemanage.store','uses'=>'VehiclemanageController@store']);
Route::post('vehiclemanage/create',['as'=>'vehiclemanage.create','uses'=>'VehiclemanageController@create']);
Route::get('vehiclemanage/edit/{id}',['as'=>'vehiclemanage.edit','uses'=>'VehiclemanageController@edit']);
Route::patch('vehiclemanage/{id}',['as'=>'vehiclemanage.update','uses'=>'VehiclemanageController@update']);
Route::get('vehiclemanage/destroy/{id}',['as'=>'vehiclemanage.destroy','uses'=>'VehiclemanageController@destroy']);
Route::get('vehiclemanage/{id}',['as'=>'vehiclemanage.show','uses'=>'VehiclemanageController@show']);


Route::resource('drivermanage','DrivermanageController');
Route::get('drivermanage',['as'=>'drivermanage.index','uses'=>'DrivermanageController@index']);
Route::post('drivermanage/store',['as'=>'drivermanage.store','uses'=>'DrivermanageController@store']);
Route::post('drivermanage/create',['as'=>'drivermanage.create','uses'=>'DrivermanageController@create']);
Route::get('drivermanage/edit/{id}',['as'=>'drivermanage.edit','uses'=>'DrivermanageController@edit']);
Route::patch('drivermanage/{id}',['as'=>'drivermanage.update','uses'=>'DrivermanageController@update']);
Route::get('drivermanage/destroy/{id}',['as'=>'drivermanage.destroy','uses'=>'DrivermanageController@destroy']);
Route::get('drivermanage/{id}',['as'=>'drivermanage.show','uses'=>'DrivermanageController@show']);

Route::resource('helpandsupport','HelpandsupportController');
Route::get('helpandsupport',['as'=>'helpandsupport.index','uses'=>'HelpandsupportController@index']);
Route::post('helpandsupport/store',['as'=>'helpandsupport.store','uses'=>'HelpandsupportController@store']);
Route::post('helpandsupport/create',['as'=>'helpandsupport.create','uses'=>'HelpandsupportController@create']);
Route::get('helpandsupport/edit/{id}',['as'=>'helpandsupport.edit','uses'=>'HelpandsupportController@edit']);
Route::patch('helpandsupport/{id}',['as'=>'helpandsupport.update','uses'=>'HelpandsupportController@update']);
Route::get('helpandsupport/destroy/{id}',['as'=>'helpandsupport.destroy','uses'=>'HelpandsupportController@destroy']);
Route::get('helpandsupport/{id}',['as'=>'helpandsupport.show','uses'=>'HelpandsupportController@show']);

Route::resource('feedback','FeedbackController');
Route::get('feedback',['as'=>'feedback.index','uses'=>'FeedbackController@index']);
Route::post('feedback/create',['as'=>'feedback.store','uses'=>'FeedbackController@store']);
Route::get('feedback/edit/{id}',['as'=>'feedback.edit','uses'=>'FeedbackController@edit']);
Route::patch('feedback/{id}',['as'=>'feedback.update','uses'=>'FeedbackController@update']);
Route::get('feedback/destroy/{id}',['as'=>'feedback.destroy','uses'=>'FeedbackController@destroy']);
Route::get('feedback/{id}',['as'=>'feedback.show','uses'=>'FeedbackController@show']);

Route::resource('mobilecirclecategory','MobileCircleCategoryController');
Route::get('mobilecirclecategory',['as'=>'mobilecirclecategory.index','uses'=>'MobileCircleCategoryController@index']);
Route::post('mobilecirclecategory/create',['as'=>'mobilecirclecategory.store','uses'=>'MobileCircleCategoryController@store']);
Route::get('mobilecirclecategory/edit/{id}',['as'=>'mobilecirclecategory.edit','uses'=>'MobileCircleCategoryController@edit']);
Route::patch('mobilecirclecategory/{id}',['as'=>'mobilecirclecategory.update','uses'=>'MobileCircleCategoryController@update']);
Route::get('mobilecirclecategory/destroy/{id}',['as'=>'mobilecirclecategory.destroy','uses'=>'MobileCircleCategoryController@destroy']);
Route::get('mobilecirclecategory/{id}',['as'=>'mobilecirclecategory.show','uses'=>'MobileCircleCategoryController@show']);

Route::resource('promotion_banner','PromotionBannerController');
Route::get('promotion_banner',['as'=>'promotion_banner.index','uses'=>'PromotionBannerController@index']);
Route::post('promotion_banner/create',['as'=>'promotion_banner.create','uses'=>'PromotionBannerController@create']);
Route::post('promotion_banner/store',['as'=>'promotion_banner.store','uses'=>'PromotionBannerController@store']);
Route::get('promotion_banner/edit/{id}',['as'=>'promotion_banner.edit','uses'=>'PromotionBannerController@edit']);
Route::patch('promotion_banner/{id}',['as'=>'promotion_banner.update','uses'=>'PromotionBannerController@update']);
Route::patch('promotion_banner/table_pdf_details/{id}',['as'=>'promotion_banner.tablePdfDetailsUpdate','uses'=>'PromotionBannerController@tablePdfDetailsUpdate']);
Route::get('promotion_banner/destroy/{id}',['as'=>'promotion_banner.destroy','uses'=>'PromotionBannerController@destroy']);
Route::get('promotion_banner/{id}',['as'=>'promotion_banner.show','uses'=>'PromotionBannerController@show']);


Route::resource('erpinventory','ErpInventoryController');
Route::get('erpinventory',['as'=>'erpinventory.index','uses'=>'ErpInventoryController@index']);
Route::post('erpinventory/create',['as'=>'erpinventory.store','uses'=>'ErpInventoryController@store']);
Route::get('erpinventory/edit/{id}',['as'=>'erpinventory.edit','uses'=>'ErpInventoryController@edit']);
Route::patch('erpinventory/{id}',['as'=>'erpinventory.update','uses'=>'ErpInventoryController@update']);
Route::get('erpinventory/destroy/{id}',['as'=>'erpinventory.destroy','uses'=>'ErpInventoryController@destroy']);
Route::get('erpinventory/{id}',['as'=>'erpinventory.show','uses'=>'ErpInventoryController@show']);


Route::resource('marquee_slider','MarqueeSliderController');
Route::get('marquee_slider',['as'=>'marquee_slider.index','uses'=>'MarqueeSliderController@index']);
Route::post('marquee_slider/create',['as'=>'marquee_slider.store','uses'=>'MarqueeSliderController@store']);
Route::get('marquee_slider/edit/{id}',['as'=>'marquee_slider.edit','uses'=>'MarqueeSliderController@edit']);
Route::patch('marquee_slider/{id}',['as'=>'marquee_slider.update','uses'=>'MarqueeSliderController@update']);
Route::get('marquee_slider/destroy/{id}',['as'=>'marquee_slider.destroy','uses'=>'MarqueeSliderController@destroy']);
Route::get('marquee_slider/{id}',['as'=>'marquee_slider.show','uses'=>'MarqueeSliderController@show']);

Route::resource('salesorder_status','OrderStatusinfoController');
Route::get('salesorder_status',['as'=>'salesorder_status.index','uses'=>'OrderStatusinfoController@index']);
Route::post('salesorder_status/store',['as'=>'salesorder_status.store','uses'=>'OrderStatusinfoController@store']);
Route::post('salesorder_status/create',['as'=>'salesorder_status.create','uses'=>'OrderStatusinfoController@create']);
Route::get('salesorder_status/edit/{id}',['as'=>'salesorder_status.edit','uses'=>'OrderStatusinfoController@edit']);
Route::patch('salesorder_status/{id}',['as'=>'salesorder_status.update','uses'=>'OrderStatusinfoController@update']);
Route::get('salesorder_status/destroy/{id}',['as'=>'salesorder_status.destroy','uses'=>'OrderStatusinfoController@destroy']);
Route::get('salesorder_status/{id}',['as'=>'salesorder_status.show','uses'=>'OrderStatusinfoController@show']);

Route::resource('popup','PopupController');
Route::get('popup',['as'=>'popuppopup.index','uses'=>'PopupController@index']);
Route::post('popup/store',['as'=>'popup.store','uses'=>'PopupController@store']);
Route::post('popup/create',['as'=>'popup.create','uses'=>'PopupController@create']);
Route::get('popup/edit/{id}',['as'=>'popup.edit','uses'=>'PopupController@edit']);
Route::patch('popup/{id}',['as'=>'popup.update','uses'=>'PopupController@update']);
Route::get('popup/destroy/{id}',['as'=>'popup.destroy','uses'=>'PopupController@destroy']);
Route::get('popup/{id}',['as'=>'popup.show','uses'=>'PopupController@show']);

Route::resource('appnotify','AppNotifyController');
Route::post('appnotify/index',['as'=>'appnotify.index','uses'=>'AppNotifyController@index']);


Route::resource('mobile_section','SectionController');
Route::get('mobile_section',['as'=>'mobile_section.index','uses'=>'SectionController@index']);
Route::post('mobile_section/create',['as'=>'mobile_section.create','uses'=>'SectionController@create']);
Route::get('mobile_section/edit/{id}',['as'=>'mobile_section.edit','uses'=>'SectionController@edit']);
Route::patch('mobile_section/{id}',['as'=>'mobile_section.update','uses'=>'SectionController@update']);
Route::get('mobile_section/destroy/{id}',['as'=>'mobile_section.destroy','uses'=>'SectionController@destroy']);
Route::get('mobile_section/{id}',['as'=>'mobile_section.show','uses'=>'SectionController@show']);
Route::get('mobile_section/editssection/{id}',['as'=>'mobile_section.editssection','uses'=>'SectionController@editssection']);
Route::patch('mobile_section/sectionstore/{id}',['as'=>'mobile_section.sectionstore','uses'=>'SectionController@sectionstore']);
Route::post('mobile_section/sectioncreate',['as'=>'mobile_section.sectioncreate','uses'=>'SectionController@sectioncreate']);
Route::post('mobile_section/sectionadd',['as'=>'mobile_section.sectionadd','uses'=>'SectionController@sectionadd']);
Route::get('mobile_section/sectiondestroy/{id}',['as'=>'mobile_section.sectiondestroy','uses'=>'SectionController@sectiondestroy']);

Route::resource('tolerance','ToleranceController');
Route::get('tolerance',['as'=>'tolerance.index','uses'=>'ToleranceController@index']);
Route::post('tolerance/create',['as'=>'tolerance.store','uses'=>'ToleranceController@store']);
Route::get('tolerance/edit/{id}',['as'=>'tolerance.edit','uses'=>'ToleranceController@edit']);
Route::patch('tolerance/{id}',['as'=>'tolerance.update','uses'=>'ToleranceController@update']);
Route::get('tolerance/destroy/{id}',['as'=>'tolerance.destroy','uses'=>'ToleranceController@destroy']);
Route::get('tolerance/{id}',['as'=>'tolerance.show','uses'=>'ToleranceController@show']);

Route::resource('newarrival','NewarrivalController');
Route::get('newarrival',['as'=>'newarrival.index','uses'=>'NewarrivalController@index']);
Route::post('newarrival/create',['as'=>'newarrival.store','uses'=>'NewarrivalController@store']);
Route::get('newarrival/edit/{id}',['as'=>'newarrival.edit','uses'=>'NewarrivalController@edit']);
Route::patch('newarrival/{id}',['as'=>'newarrival.update','uses'=>'NewarrivalController@update']);
Route::get('newarrival/destroy/{id}',['as'=>'newarrival.destroy','uses'=>'NewarrivalController@destroy']);
Route::get('newarrival/{id}',['as'=>'newarrival.show','uses'=>'NewarrivalController@show']);


Route::resource('pushnotification','PushNotificationController');
Route::get('pushnotification',['as'=>'pushnotification.index','uses'=>'PushNotificationController@index']);
Route::post('pushnotification/create',['as'=>'pushnotification.store','uses'=>'PushNotificationController@store']);
Route::get('pushnotification/edit/{id}',['as'=>'pushnotification.edit','uses'=>'PushNotificationController@edit']);
Route::patch('pushnotification/{id}',['as'=>'pushnotification.update','uses'=>'PushNotificationController@update']);
Route::get('pushnotification/destroy/{id}',['as'=>'pushnotification.destroy','uses'=>'PushNotificationController@destroy']);
Route::get('pushnotification/{id}',['as'=>'pushnotification.show','uses'=>'PushNotificationController@show']);

Route::resource('importcategory','ImportcategoryController');
Route::get('importcategory',['as'=>'importcategory.index','uses'=>'ImportcategoryController@index']);
Route::post('importcategory/create',['as'=>'importcategory.store','uses'=>'ImportcategoryController@store']);
Route::get('importcategory/edit/{id}',['as'=>'importcategory.edit','uses'=>'ImportcategoryController@edit']);
Route::post('importcategory/update',['as'=>'importcategory.update','uses'=>'ImportcategoryController@update']);
Route::get('importcategory/destroy/{id}',['as'=>'importcategory.destroy','uses'=>'ImportcategoryController@destroy']);
Route::get('importcategory/{id}',['as'=>'importcategory.show','uses'=>'ImportcategoryController@show']);
Route::delete('importcategoryDeleteAll',['as'=>'importcategory.multiDelete','uses'=>'ImportcategoryController@multiDelete']);


Route::resource('productimagedelete','ProductimagedeleteController');
Route::get('productimagedelete',['as'=>'productimagedelete.index','uses'=>'ProductimagedeleteController@index']);
Route::post('productimagedelete/store',['as'=>'productimagedelete.store','uses'=>'ProductimagedeleteController@store']);
Route::get('productimagedelete/edit/{id}',['as'=>'productimagedelete.edit','uses'=>'ProductimagedeleteController@edit']);
Route::post('productimagedelete/update',['as'=>'productimagedelete.update','uses'=>'ProductimagedeleteController@update']);
Route::get('productimagedelete/destroy/{id}',['as'=>'productimagedelete.destroy','uses'=>'ProductimagedeleteController@destroy']);
Route::get('productimagedelete/{id}',['as'=>'productimagedelete.show','uses'=>'ProductimagedeleteController@show']);
Route::delete('productimagedeleteDeleteAll',['as'=>'productimagedelete.multiDelete','uses'=>'ProductimagedeleteController@multiDelete']);


Route::resource('payment','PaymentSetupController');
Route::get('payment',['as'=>'payment.index','uses'=>'PaymentSetupController@index']);
Route::post('payment/create',['as'=>'payment.store','uses'=>'PaymentSetupController@store']);
Route::get('payment/edit/{id}',['as'=>'payment.edit','uses'=>'PaymentSetupController@edit']);
Route::patch('payment/{id}',['as'=>'payment.update','uses'=>'PaymentSetupController@update']);
Route::get('payment/destroy/{id}',['as'=>'payment.destroy','uses'=>'PaymentSetupController@destroy']);
Route::get('payment/{id}',['as'=>'payment.show','uses'=>'PaymentSetupController@show']);

});